@@ -1,21 +1,19 @@
 /*
- * SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef LDAPCLIENTSEARCHCONFIG_H
-#define LDAPCLIENTSEARCHCONFIG_H
+#pragma once
 
 #include "kldap_export.h"
 
 #include <QObject>
-
-class KConfigGroup;
+#include <memory>
 class KConfig;
 
-namespace KLDAP {
-class LdapServer;
+namespace KLDAP
+{
 class LdapClient;
 /**
  * @brief The LdapClientSearchConfig class
@@ -26,19 +24,17 @@ class KLDAP_EXPORT LdapClientSearchConfig : public QObject
     Q_OBJECT
 public:
     explicit LdapClientSearchConfig(QObject *parent = nullptr);
-    ~LdapClientSearchConfig();
+    ~LdapClientSearchConfig() override;
 
     /**
      * Returns the global config object, which stores the LdapClient configurations.
      */
     static KConfig *config();
 
-
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    class LdapClientSearchConfigPrivate;
+    std::unique_ptr<LdapClientSearchConfigPrivate> const d;
 };
 }
 
-#endif // LDAPCLIENTSEARCHCONFIG_H
