@@ -1,15 +1,15 @@
 /*
- * SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef LDAPWIDGETITEM_H
-#define LDAPWIDGETITEM_H
+#pragma once
 
 #include <QListWidget>
 #include <kldap/ldapserver.h>
-namespace KLDAP {
+namespace KLDAP
+{
 class LdapWidgetItem : public QListWidgetItem
 {
 public:
@@ -29,4 +29,3 @@ private:
 };
 }
 
-#endif // LDAPWIDGETITEM_H
