@@ -1,7 +1,7 @@
 /*
  * AccessControlPage.cpp - implementation of the access control page
  *
- * Copyright (c) 2016-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2016-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -252,8 +252,13 @@ void AccessControlPage::moveAccessControlRuleUp()
 
 void AccessControlPage::testUserGroupsAccessControl()
 {
-	QString username = QInputDialog::getText( this, tr( "Enter username" ),
-										  tr( "Please enter a user login name whose access permissions to test:" ) );
+	const auto username = QInputDialog::getText( this, tr( "Enter username" ),
+												 tr( "Please enter a user login name whose access permissions to test:" ) );
+
+	if (username.isEmpty())
+	{
+		return;
+	}
 
 	if( AccessControlProvider().processAuthorizedGroups( username ) )
 	{
