@@ -1,7 +1,7 @@
 /*
  * MainWindow.cpp - implementation of MainWindow class
  *
- * Copyright (c) 2010-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2010-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -22,6 +22,7 @@
  *
  */
 
+#include <QActionGroup>
 #include <QDir>
 #include <QProcess>
 #include <QCloseEvent>
@@ -29,6 +30,8 @@
 #include <QPushButton>
 #include <QMessageBox>
 #include <QScrollBar>
+#include <QSettings>
+#include <QTimer>
 
 #include "Configuration/JsonStore.h"
 #include "Configuration/UiMapping.h"
@@ -50,7 +53,7 @@ MainWindow::MainWindow( QWidget* parent ) :
 {
 	ui->setupUi( this );
 
-	setWindowTitle( tr( "%1 Configurator %2" ).arg( VeyonCore::applicationName(), VeyonCore::version() ) );
+	setWindowTitle( tr( "%1 Configurator %2" ).arg( VeyonCore::applicationName(), VeyonCore::versionString() ) );
 
 	loadConfigurationPagePlugins();
 
