@@ -1,7 +1,7 @@
 /*
  * AccessControlRule.cpp - implementation of the AccessControlRule class
  *
- * Copyright (c) 2016-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2016-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -68,9 +68,9 @@ AccessControlRule::AccessControlRule(const QJsonValue &jsonValue) :
 		m_invertConditions = json[QStringLiteral("InvertConditions")].toBool();
 		m_ignoreConditions = json[QStringLiteral("IgnoreConditions")].toBool();
 
-		auto parameters = json[QStringLiteral("Parameters")].toArray();
+		const auto parameters = json[QStringLiteral("Parameters")].toArray();
 
-		for( auto parametersValue : parameters )
+		for( const auto& parametersValue : parameters )
 		{
 			QJsonObject parametersObj = parametersValue.toObject();
 			auto condition = static_cast<Condition>( parametersObj[QStringLiteral("Condition")].toInt() );
