@@ -1,7 +1,7 @@
 /*
  * FeatureManager.cpp - implementation of the FeatureManager class
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -24,9 +24,11 @@
 
 #include "FeatureManager.h"
 #include "FeatureMessage.h"
+#include "FeatureWorkerManager.h"
 #include "PluginInterface.h"
 #include "PluginManager.h"
 #include "VeyonConfiguration.h"
+#include "VeyonServerInterface.h"
 
 Q_DECLARE_METATYPE(Feature)
 Q_DECLARE_METATYPE(FeatureMessage)
@@ -96,7 +98,32 @@ const Feature& FeatureManager::feature( Feature::Uid featureUid ) const
 
 
 
-Plugin::Uid FeatureManager::pluginUid( const Feature& feature ) const
+const FeatureList& FeatureManager::relatedFeatures( Feature::Uid featureUid ) const
+{
+	return features( pluginUid( featureUid ) );
+}
+
+
+
+Feature::Uid FeatureManager::metaFeatureUid( Feature::Uid featureUid ) const
+{
+	for( const auto& featureInterface : m_featurePluginInterfaces )
+	{
+		for( const auto& feature : featureInterface->featureList() )
+		{
+			if( feature.uid() == featureUid )
+			{
+				return featureInterface->metaFeature( featureUid );
+			}
+		}
+	}
+
+	return {};
+}
+
+
+
+Plugin::Uid FeatureManager::pluginUid( Feature::Uid featureUid ) const
 {
 	for( auto pluginObject : m_pluginObjects )
 	{
@@ -104,7 +131,10 @@ Plugin::Uid FeatureManager::pluginUid( const Feature& feature ) const
 		auto featurePluginInterface = qobject_cast<FeatureProviderInterface *>( pluginObject );
 
 		if( pluginInterface && featurePluginInterface &&
-				featurePluginInterface->featureList().contains( feature ) )
+			std::find_if( featurePluginInterface->featureList().begin(),
+						  featurePluginInterface->featureList().end(),
+						  [&featureUid]( const Feature& feature ) { return feature.uid() == featureUid; } )
+				!= featurePluginInterface->featureList().end() )
 		{
 			return pluginInterface->uid();
 		}
@@ -124,8 +154,6 @@ void FeatureManager::controlFeature( Feature::Uid featureUid,
 	{
 		featureInterface->controlFeature( featureUid, operation, arguments, computerControlInterfaces );
 	}
-
-	updateActiveFeatures( computerControlInterfaces );
 }
 
 
@@ -134,22 +162,20 @@ void FeatureManager::startFeature( VeyonMasterInterface& master,
 								   const Feature& feature,
 								   const ComputerControlInterfaceList& computerControlInterfaces ) const
 {
-	vDebug() << "feature" << feature.name() << feature.uid() << computerControlInterfaces;
+	vDebug() << computerControlInterfaces << feature.name();
 
 	for( auto featureInterface : qAsConst( m_featurePluginInterfaces ) )
 	{
 		featureInterface->startFeature( master, feature, computerControlInterfaces );
 	}
 
-	if( feature.testFlag( Feature::Mode ) )
+	if( feature.testFlag( Feature::Flag::Mode ) )
 	{
 		for( const auto& controlInterface : computerControlInterfaces )
 		{
 			controlInterface->setDesignatedModeFeature( feature.uid() );
 		}
 	}
-
-	updateActiveFeatures( computerControlInterfaces );
 }
 
 
@@ -158,7 +184,7 @@ void FeatureManager::stopFeature( VeyonMasterInterface& master,
 								  const Feature& feature,
 								  const ComputerControlInterfaceList& computerControlInterfaces ) const
 {
-	vDebug() << "feature" << feature.name() << feature.uid() << computerControlInterfaces;
+	vDebug() << computerControlInterfaces << feature.name();
 
 	for( const auto& featureInterface : qAsConst( m_featurePluginInterfaces ) )
 	{
@@ -172,88 +198,82 @@ void FeatureManager::stopFeature( VeyonMasterInterface& master,
 			controlInterface->setDesignatedModeFeature( Feature::Uid() );
 		}
 	}
-
-	updateActiveFeatures( computerControlInterfaces );
 }
 
 
 
-void FeatureManager::updateActiveFeatures( const ComputerControlInterfaceList& computerControlInterfaces ) const
+void FeatureManager::handleFeatureMessage(ComputerControlInterface::Pointer computerControlInterface,
+										  const FeatureMessage& message) const
 {
-	for( const auto& controlInterface : computerControlInterfaces )
-	{
-		controlInterface->updateActiveFeatures();
-	}
-}
-
-
-
-bool FeatureManager::handleFeatureMessage( ComputerControlInterface::Pointer computerControlInterface,
-										  const FeatureMessage& message ) const
-{
-	vDebug() << "feature" << feature(message.featureUid()).name()
-			 << "command" << message.command()
-			 << "arguments" << message.arguments();
-
-	bool handled = false;
+	vDebug() << computerControlInterface << message;
 
 	for( const auto& featureInterface : qAsConst( m_featurePluginInterfaces ) )
 	{
-		if( featureInterface->handleFeatureMessage( computerControlInterface, message ) )
-		{
-			handled = true;
-		}
+		featureInterface->handleFeatureMessage(computerControlInterface, message);
 	}
-
-	return handled;
 }
 
 
 
-bool FeatureManager::handleFeatureMessage( VeyonServerInterface& server,
-										   const MessageContext& messageContext,
-										   const FeatureMessage& message ) const
+void FeatureManager::handleFeatureMessage(VeyonServerInterface& server,
+										  const MessageContext& messageContext,
+										  const FeatureMessage& message) const
 {
-	vDebug() << "feature" << feature(message.featureUid()).name()
-			 << "command" << message.command()
-			 << "arguments" << message.arguments();
+	vDebug() << "[SERVER]" << message;
 
 	if( VeyonCore::config().disabledFeatures().contains( message.featureUid().toString() ) )
 	{
 		vWarning() << "ignoring message as feature" << message.featureUid() << "is disabled by configuration!";
-		return false;
+		return;
 	}
 
-	bool handled = false;
-
 	for( const auto& featureInterface : qAsConst( m_featurePluginInterfaces ) )
 	{
-		if( featureInterface->handleFeatureMessage( server, messageContext, message ) )
-		{
-			handled = true;
-		}
+		featureInterface->handleFeatureMessage(server, messageContext, message);
 	}
-
-	return handled;
 }
 
 
 
-bool FeatureManager::handleFeatureMessage( VeyonWorkerInterface& worker, const FeatureMessage& message ) const
+void FeatureManager::handleFeatureMessage(VeyonWorkerInterface& worker, const FeatureMessage& message) const
 {
-	vDebug() << "feature" << feature(message.featureUid()).name()
-			 << "command" << message.command()
-			 << "arguments" << message.arguments();
-
-	bool handled = false;
+	vDebug() << "[WORKER]" << message;
 
 	for( const auto& featureInterface : qAsConst( m_featurePluginInterfaces ) )
 	{
-		if( featureInterface->handleFeatureMessage( worker, message ) )
+		featureInterface->handleFeatureMessage(worker, message);
+	}
+}
+
+
+
+void FeatureManager::sendAsyncFeatureMessages(VeyonServerInterface& server,
+												  const MessageContext& messageContext) const
+{
+
+	for (const auto& featureInterface : qAsConst(m_featurePluginInterfaces))
+	{
+		featureInterface->sendAsyncFeatureMessages(server, messageContext);
+	}
+}
+
+
+
+FeatureUidList FeatureManager::activeFeatures( VeyonServerInterface& server ) const
+{
+	FeatureUidList features;
+
+	for( const auto& featureInterface : qAsConst( m_featurePluginInterfaces ) )
+	{
+		for( const auto& feature : featureInterface->featureList() )
 		{
-			handled = true;
+			if( featureInterface->isFeatureActive( server, feature.uid() ) ||
+				server.featureWorkerManager().isWorkerRunning( feature.uid() ) )
+			{
+				features.append( feature.uid() );
+			}
 		}
 	}
 
-	return handled;
+	return features;
 }
