@@ -1,7 +1,7 @@
 /*
  * FeatureMessage.cpp - implementation of a message encapsulation class for features
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -22,6 +22,7 @@
  *
  */
 
+#include "FeatureManager.h"
 #include "FeatureMessage.h"
 #include "VariantArrayMessage.h"
 
@@ -77,3 +78,14 @@ bool FeatureMessage::receive( QIODevice* ioDevice )
 
 	return false;
 }
+
+
+
+QDebug operator<<(QDebug stream, const FeatureMessage& message)
+{
+	stream << QStringLiteral("FeatureMessage(%1,%2,%3)")
+				  .arg(VeyonCore::featureManager().feature(message.featureUid()).name())
+				  .arg(message.command())
+				  .arg(VeyonCore::stringify(message.arguments())).toUtf8().constData();
+	return stream;
+}
