@@ -1,7 +1,7 @@
 /*
  * HostAddress.cpp - implementation of HostAddress class
  *
- * Copyright (c) 2019-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2019-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -29,6 +29,8 @@
 #include "HostAddress.h"
 
 
+QString HostAddress::s_cachedLocalFQDN;
+
 HostAddress::HostAddress( const QString& address ) :
 	m_type( determineType( address ) ),
 	m_address( address )
@@ -155,26 +157,12 @@ int HostAddress::parsePortNumber( const QString& address )
 
 QString HostAddress::localFQDN()
 {
-	const auto localHostName = QHostInfo::localHostName();
-	const auto type = determineType( localHostName );
-
-	switch( type )
+	if( s_cachedLocalFQDN.isEmpty() )
 	{
-	case Type::HostName:
-		if( QHostInfo::localDomainName().isEmpty() == false )
-		{
-			return localHostName + QStringLiteral( "." ) + QHostInfo::localDomainName();
-		}
-
-	case Type::FullyQualifiedDomainName:
-		return localHostName;
-
-	default:
-		vWarning() << "Could not determine local host name:" << localHostName;
-		break;
+		s_cachedLocalFQDN = resolveLocalFQDN();
 	}
 
-	return HostAddress( localHostName ).tryConvert( Type::FullyQualifiedDomainName );
+	return s_cachedLocalFQDN;
 }
 
 
@@ -313,3 +301,29 @@ QString HostAddress::fqdnToHostName( const QString& fqdn )
 		return fqdn.split( QLatin1Char( '.' ) ).constFirst();
 #endif
 }
+
+
+
+QString HostAddress::resolveLocalFQDN()
+{
+	const auto localHostName = QHostInfo::localHostName();
+	const auto type = determineType( localHostName );
+
+	switch( type )
+	{
+	case Type::HostName:
+		if( QHostInfo::localDomainName().isEmpty() == false )
+		{
+			return localHostName + QStringLiteral( "." ) + QHostInfo::localDomainName();
+		}
+
+	case Type::FullyQualifiedDomainName:
+		return localHostName;
+
+	default:
+		vWarning() << "Could not determine local host name:" << localHostName;
+		break;
+	}
+
+	return HostAddress( localHostName ).tryConvert( Type::FullyQualifiedDomainName );
+}
