@@ -40,10 +40,6 @@ QMutex Logger::s_instanceMutex;
 Logger::Logger( const QString &appName ) :
 	m_logLevel( LogLevel::Default ),
 	m_logMutex(),
-	m_lastMessageLevel( LogLevel::Nothing ),
-	m_lastMessage(),
-	m_lastMessageCount( 0 ),
-	m_logToSystem( false ),
 	m_appName( QStringLiteral( "Veyon" ) + appName ),
 	m_logFile( nullptr ),
 	m_logFileSizeLimit( -1 ),
@@ -56,14 +52,22 @@ Logger::Logger( const QString &appName ) :
 	s_instance = this;
 	s_instanceMutex.unlock();
 
+	m_logToSystem = VeyonCore::config().logToSystem();
+	m_logToStdErr = VeyonCore::config().logToStdErr();
+
 	auto configuredLogLevel = VeyonCore::config().logLevel();
 	if( qEnvironmentVariableIsSet( logLevelEnvironmentVariable() ) )
 	{
-		configuredLogLevel = static_cast<LogLevel>( qEnvironmentVariableIntValue( logLevelEnvironmentVariable() ) );
+		configuredLogLevel = logLevelFromString(
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+								 qEnvironmentVariable(logLevelEnvironmentVariable())
+#else
+								 QLatin1String(qgetenv(logLevelEnvironmentVariable()))
+#endif
+								 );
 	}
 
 	m_logLevel = qBound( LogLevel::Min, configuredLogLevel, LogLevel::Max );
-	m_logToSystem = VeyonCore::config().logToSystem();
 
 	if( m_logLevel > LogLevel::Nothing )
 	{
@@ -105,6 +109,38 @@ Logger::~Logger()
 
 
 
+Logger::LogLevel Logger::logLevelFromString(const QString& logLevelString)
+{
+	if (logLevelString.startsWith(QLatin1String("debug")))
+	{
+		return LogLevel::Debug;
+	}
+
+	if (logLevelString.startsWith(QLatin1String("info")))
+	{
+		return LogLevel::Info;
+	}
+
+	if (logLevelString.startsWith(QLatin1String("warn")))
+	{
+		return LogLevel::Warning;
+	}
+
+	if (logLevelString.startsWith(QLatin1String("err")))
+	{
+		return LogLevel::Error;
+	}
+
+	if (logLevelString.startsWith(QLatin1String("crit")))
+	{
+		return LogLevel::Critical;
+	}
+
+	return LogLevel(logLevelString.toUInt());
+}
+
+
+
 
 void Logger::initLogFile()
 {
@@ -342,7 +378,7 @@ void Logger::outputMessage( const QString& message )
 		}
 	}
 
-	if( VeyonCore::config().logToStdErr() )
+	if (m_logToStdErr)
 	{
 		fprintf( stderr, "%s", message.toUtf8().constData() );
 		fflush( stderr );
