@@ -1,7 +1,7 @@
 /*
  * TranslationLoader.cpp - implementation of TranslationLoader class
  *
- * Copyright (c) 2020-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2020-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -23,6 +23,7 @@
  */
 
 #include <QCoreApplication>
+#include <QRegularExpression>
 #include <QTranslator>
 
 #include "TranslationLoader.h"
@@ -37,33 +38,38 @@ TranslationLoader::TranslationLoader( const QString& resourceName )
 
 
 
-QLocale TranslationLoader::load( const QString& resourceName )
+bool TranslationLoader::load( const QString& resourceName )
 {
 	QLocale configuredLocale( QLocale::C );
 
-	QRegExp localeRegEx( QStringLiteral( "[^(]*\\(([^)]*)\\)") );
-	if( localeRegEx.indexIn( VeyonCore::config().uiLanguage() ) == 0 )
+	const auto configuredLocaleMatch = QRegularExpression{ QStringLiteral( "[^(]*\\(([^)]*)\\)") }
+										   .match( VeyonCore::config().uiLanguage() );
+	if( configuredLocaleMatch.hasMatch() )
 	{
-		configuredLocale = QLocale( localeRegEx.cap( 1 ) );
+		configuredLocale = QLocale( configuredLocaleMatch.captured( 1 ) );
 	}
 
 	if( configuredLocale.language() != QLocale::English &&
 		VeyonCore::instance()->findChild<QTranslator *>( resourceName ) == nullptr )
 	{
+		const auto translationsDirectory = resourceName.startsWith( QLatin1String("qt") )
+											  ? VeyonCore::qtTranslationsDirectory()
+											  : VeyonCore::translationsDirectory();
+
 		auto translator = new QTranslator( VeyonCore::instance() );
 		translator->setObjectName( resourceName );
 
 		if( configuredLocale == QLocale::C ||
 			translator->load( QStringLiteral( "%1_%2.qm" ).arg( resourceName, configuredLocale.name() ),
-							  VeyonCore::translationsDirectory() ) == false )
+							  translationsDirectory ) == false )
 		{
 			configuredLocale = QLocale::system(); // Flawfinder: ignore
 
 			if( translator->load( QStringLiteral( "%1_%2.qm" ).arg( resourceName, configuredLocale.name() ),
-								  VeyonCore::translationsDirectory() ) == false )
+								  translationsDirectory ) == false )
 			{
-				translator->load( QStringLiteral( "%1_%2.qm" ).arg( resourceName, configuredLocale.language() ),
-								  VeyonCore::translationsDirectory() );
+				delete translator;
+				return false;
 			}
 		}
 
@@ -72,5 +78,5 @@ QLocale TranslationLoader::load( const QString& resourceName )
 		QCoreApplication::installTranslator( translator );
 	}
 
-	return configuredLocale;
+	return true;
 }
