@@ -1,7 +1,7 @@
 /*
  * UserGroupsBackendManager.cpp - implementation of UserGroupsBackendManager
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -28,10 +28,7 @@
 
 
 UserGroupsBackendManager::UserGroupsBackendManager( QObject* parent ) :
-	QObject( parent ),
-	m_backends(),
-	m_defaultBackend( nullptr ),
-	m_accessControlBackend( nullptr )
+	QObject( parent )
 {
 	for( auto pluginObject : qAsConst( VeyonCore::pluginManager().pluginObjects() ) )
 	{
