@@ -1,7 +1,7 @@
 /*
  * VariantArrayMessage.cpp - class for sending/receiving a variant array as message
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -73,21 +73,21 @@ bool VariantArrayMessage::receive()
 
 	if( m_ioDevice->read( reinterpret_cast<char *>( &messageSize ), sizeof(messageSize) ) != sizeof(messageSize) ) // Flawfinder: ignore
 	{
-		vWarning() << "could not read message size!";
+		vDebug() << "could not read message size!";
 		return false;
 	}
 
 	messageSize = qFromBigEndian(messageSize);
 	if( messageSize > MaxMessageSize )
 	{
-		vCritical() << "invalid message size" << messageSize;
+		vDebug() << "invalid message size" << messageSize;
 		return false;
 	}
 
 	const auto data = m_ioDevice->read( messageSize ); // Flawfinder: ignore
 	if( data.size() != static_cast<qint64>( messageSize ) )
 	{
-		vWarning() << "could not read message data!";
+		vDebug() << "could not read message data!";
 		return false;
 	}
 
