@@ -37,7 +37,6 @@
 #include <QSysInfo>
 
 #include "BuiltinFeatures.h"
-#include "ComputerControlInterface.h"
 #include "FeatureManager.h"
 #include "Filesystem.h"
 #include "HostAddress.h"
@@ -98,13 +97,15 @@ VeyonCore::VeyonCore( QCoreApplication* application, Component component, const
 
 	initSystemInfo();
 
-	Q_EMIT initialized();
+	Q_EMIT initialized(); // clazy:exclude=incorrect-emit
 }
 
 
 
 VeyonCore::~VeyonCore()
 {
+	vDebug();
+
 	delete m_featureManager;
 	m_featureManager = nullptr;
 
