@@ -1,7 +1,7 @@
 /*
  * VncViewWidget.cpp - VNC viewer widget
  *
- * Copyright (c) 2006-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -23,42 +23,29 @@
  */
 
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QMouseEvent>
 #include <QPainter>
-#include <QtMath>
+#include <QScreen>
+#include <QWindow>
 
-#include "ProgressWidget.h"
 #include "VeyonConnection.h"
 #include "VncConnection.h"
 #include "VncViewWidget.h"
 
 
-VncViewWidget::VncViewWidget( const QString& host, int port, QWidget* parent, Mode mode, const QRect& viewport ) :
+VncViewWidget::VncViewWidget( const ComputerControlInterface::Pointer& computerControlInterface,
+							  QRect viewport, QWidget* parent ) :
 	QWidget( parent ),
-	VncView( new VncConnection( QCoreApplication::instance() ) ),
-	m_veyonConnection( new VeyonConnection( connection() ) )
+	VncView( computerControlInterface )
 {
 	setViewport( viewport );
 
 	connectUpdateFunctions( this );
 
-	connection()->setHost( host );
-	connection()->setPort( port );
+	connect( connection(), &VncConnection::stateChanged, this, &VncViewWidget::updateConnectionState );
+	connect( &m_busyIndicatorTimer, &QTimer::timeout, this, QOverload<>::of(&QWidget::repaint) );
 
-	if( mode == DemoMode )
-	{
-		connection()->setQuality( VncConnection::Quality::Default );
-		m_establishingConnectionWidget = new ProgressWidget(
-			tr( "Establishing connection to %1 ..." ).arg( connection()->host() ),
-			QStringLiteral( ":/core/watch%1.png" ), 16, this );
-		connect( connection(), &VncConnection::stateChanged,
-				 this, &VncViewWidget::updateConnectionState );
-	}
-	else if( mode == RemoteControlMode )
-	{
-		connection()->setQuality( VncConnection::Quality::RemoteControl );
-	}
+	connection()->setQuality( VncConnection::Quality::Default );
 
 	// set up mouse border signal timer
 	m_mouseBorderSignalTimer.setSingleShot( true );
@@ -76,12 +63,15 @@ VncViewWidget::VncViewWidget( const QString& host, int port, QWidget* parent, Mo
 
 	show();
 
-	resize( QApplication::desktop()->availableGeometry( this ).size() - QSize( 10, 30 ) );
-
-	setFocusPolicy( Qt::StrongFocus );
+	setFocusPolicy( Qt::WheelFocus );
 	setFocus();
 
-	connection()->start();
+	setAttribute( Qt::WA_OpaquePaintEvent );
+	installEventFilter( this );
+
+	setMouseTracking( true );
+
+	updateConnectionState();
 }
 
 
@@ -90,20 +80,38 @@ VncViewWidget::~VncViewWidget()
 {
 	// do not receive any signals during connection shutdown
 	connection()->disconnect( this );
-
-	unpressModifiers();
-
-	delete m_veyonConnection;
-	m_veyonConnection = nullptr;
-
-	connection()->stopAndDeleteLater();
 }
 
 
 
 QSize VncViewWidget::sizeHint() const
 {
-	return effectiveFramebufferSize();
+	QSize availableSize{QGuiApplication::primaryScreen()->availableVirtualSize()};
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+	const auto* windowScreen = windowHandle() ? windowHandle()->screen() : nullptr;
+#else
+	const auto* windowScreen = screen();
+#endif
+	if (windowScreen)
+	{
+		availableSize = windowScreen->availableVirtualSize();
+	}
+
+	availableSize -= window()->frameSize() - window()->size();
+
+	const auto size = effectiveFramebufferSize();
+	if (size.isEmpty())
+	{
+		return availableSize;
+	}
+
+	if (size.width() > availableSize.width() ||
+		size.height() > availableSize.height())
+	{
+		return size.scaled(availableSize, Qt::KeepAspectRatio);
+	}
+
+	return size;
 }
 
 
@@ -150,39 +158,15 @@ void VncViewWidget::setViewCursor(const QCursor& cursor)
 
 
 
-void VncViewWidget::updateFramebufferSize( int w, int h )
+void VncViewWidget::updateGeometry()
 {
-	VncView::updateFramebufferSize( w, h );
-
-	resize( w, h );
+	resize( effectiveFramebufferSize() );
 
 	Q_EMIT sizeHintChanged();
 }
 
 
 
-void VncViewWidget::updateImage( int x, int y, int w, int h )
-{
-	if( m_initDone == false )
-	{
-		setAttribute( Qt::WA_OpaquePaintEvent );
-		installEventFilter( this );
-
-		setMouseTracking( true ); // get mouse events even when there is no mousebutton pressed
-		setFocusPolicy( Qt::WheelFocus );
-
-		resize( sizeHint() );
-
-		Q_EMIT connectionEstablished();
-		m_initDone = true;
-
-	}
-
-	VncView::updateImage( x, y, w, h );
-}
-
-
-
 bool VncViewWidget::event( QEvent* event )
 {
 	return VncView::handleEvent( event ) || QWidget::event( event );
@@ -273,6 +257,7 @@ void VncViewWidget::paintEvent( QPaintEvent* paintEvent )
 	if( image.isNull() || image.format() == QImage::Format_Invalid )
 	{
 		p.fillRect( paintEvent->rect(), Qt::black );
+		drawBusyIndicator( &p );
 		return;
 	}
 
@@ -292,15 +277,9 @@ void VncViewWidget::paintEvent( QPaintEvent* paintEvent )
 		p.drawImage( { 0, 0 }, image, source );
 	}
 
-	if( viewOnly() && cursorShape().isNull() == false )
+	if( connection()->state() != VncConnection::State::Connected )
 	{
-		const auto cursorRect = mapFromFramebuffer( QRect( cursorPos() - cursorHot(), cursorShape().size() ) );
-		// parts of cursor within updated region?
-		if( paintEvent->region().intersects( cursorRect ) )
-		{
-			// then repaint it
-			p.drawPixmap( cursorRect.topLeft(), cursorShape() );
-		}
+		drawBusyIndicator( &p );
 	}
 
 	// draw black borders if neccessary
@@ -323,11 +302,6 @@ void VncViewWidget::resizeEvent( QResizeEvent* event )
 {
 	update();
 
-	if( m_establishingConnectionWidget )
-	{
-		m_establishingConnectionWidget->move( 10, 10 );
-	}
-
 	updateLocalCursor();
 
 	QWidget::resizeEvent( event );
@@ -335,10 +309,50 @@ void VncViewWidget::resizeEvent( QResizeEvent* event )
 
 
 
+void VncViewWidget::drawBusyIndicator( QPainter* painter )
+{
+	static constexpr int BusyIndicatorSize = 100;
+	static constexpr int BusyIndicatorSpeed = 5;
+
+	QRect drawingRect{
+		( width() - BusyIndicatorSize ) / 2,
+		( height() - BusyIndicatorSize ) / 2,
+		BusyIndicatorSize, BusyIndicatorSize,
+		};
+
+	QColor color(QStringLiteral("#00acdc"));
+	QConicalGradient gradient;
+	gradient.setCenter(drawingRect.center());
+	gradient.setAngle((360 - m_busyIndicatorState) % 360);
+	gradient.setColorAt(0, color);
+	color.setAlpha(0);
+	gradient.setColorAt(0.75, color);
+	color.setAlpha(255);
+	gradient.setColorAt(1, color);
+
+	QPen pen(QBrush(gradient), 20);
+	pen.setCapStyle(Qt::RoundCap);
+	painter->setPen(pen);
+
+	painter->setRenderHint(QPainter::Antialiasing);
+	painter->drawArc( drawingRect,
+					  ( 360 - ( m_busyIndicatorState % 360 ) ) * 16, 270 * 16 );
+
+	m_busyIndicatorState += BusyIndicatorSpeed;
+}
+
+
+
 void VncViewWidget::updateConnectionState()
 {
-	if( m_establishingConnectionWidget )
+	if( connection()->state() != VncConnection::State::Connected )
 	{
-		m_establishingConnectionWidget->setVisible( connection()->state() != VncConnection::State::Connected );
+		m_busyIndicatorTimer.start( BusyIndicatorUpdateInterval );
+	}
+	else
+	{
+		m_busyIndicatorTimer.stop();
+
+		resize( effectiveFramebufferSize() );
 	}
 }
