@@ -1,7 +1,7 @@
 /*
  * ComputerControlListModel.cpp - data model for computer control objects
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -105,8 +105,11 @@ QVariant ComputerControlListModel::data( const QModelIndex& index, int role ) co
 	case StateRole:
 		return QVariant::fromValue( computerControl->state() );
 
-	case ScreenRole:
-		return computerControl->screen();
+	case UserLoginNameRole:
+		return computerControl->userLoginName();
+
+	case FramebufferRole:
+		return computerControl->framebuffer();
 
 	case ControlInterfaceRole:
 		return QVariant::fromValue( computerControl );
@@ -139,7 +142,7 @@ void ComputerControlListModel::updateComputerScreenSize()
 
 	for( auto& controlInterface : m_computerControlInterfaces )
 	{
-		controlInterface->setScaledScreenSize( newSize );
+		controlInterface->setScaledFramebufferSize( newSize );
 	}
 
 	if( m_computerScreenSize != newSize )
@@ -255,14 +258,14 @@ QModelIndex ComputerControlListModel::interfaceIndex( ComputerControlInterface*
 
 void ComputerControlListModel::updateState( const QModelIndex& index )
 {
-	Q_EMIT dataChanged( index, index, { Qt::DisplayRole, Qt::DecorationRole, Qt::ToolTipRole, ScreenRole } );
+	Q_EMIT dataChanged( index, index, { Qt::DisplayRole, Qt::DecorationRole, Qt::ToolTipRole, FramebufferRole } );
 }
 
 
 
 void ComputerControlListModel::updateScreen( const QModelIndex& index )
 {
-	Q_EMIT dataChanged( index, index, { Qt::DecorationRole, ScreenRole } );
+	Q_EMIT dataChanged( index, index, { Qt::DecorationRole, FramebufferRole } );
 }
 
 
@@ -292,15 +295,10 @@ void ComputerControlListModel::startComputerControlInterface( ComputerControlInt
 {
 	controlInterface->start( computerScreenSize(), ComputerControlInterface::UpdateMode::Monitoring );
 
-	connect( controlInterface, &ComputerControlInterface::featureMessageReceived, this,
-			 [=]( const FeatureMessage& featureMessage, const ComputerControlInterface::Pointer& computerControlInterface ) {
-				 m_master->featureManager().handleFeatureMessage( computerControlInterface, featureMessage );
-	} );
-
-	connect( controlInterface, &ComputerControlInterface::screenSizeChanged,
+	connect( controlInterface, &ComputerControlInterface::framebufferSizeChanged,
 			 this, &ComputerControlListModel::updateComputerScreenSize );
 
-	connect( controlInterface, &ComputerControlInterface::screenUpdated,
+	connect( controlInterface, &ComputerControlInterface::framebufferUpdated,
 			 this, [=] () { updateScreen( interfaceIndex( controlInterface ) ); } );
 
 	connect( controlInterface, &ComputerControlInterface::activeFeaturesChanged,
@@ -317,7 +315,7 @@ void ComputerControlListModel::startComputerControlInterface( ComputerControlInt
 
 void ComputerControlListModel::stopComputerControlInterface( const ComputerControlInterface::Pointer& controlInterface )
 {
-	m_master->stopAllModeFeatures( { controlInterface } );
+	m_master->stopAllFeatures( { controlInterface } );
 
 	controlInterface->disconnect( &m_master->computerManager() );
 
@@ -368,26 +366,26 @@ QImage ComputerControlListModel::computerDecorationRole( const ComputerControlIn
 	{
 	case ComputerControlInterface::State::Connected:
 	{
-		const auto image = controlInterface->scaledScreen();
+		const auto image = controlInterface->scaledFramebuffer();
 		if( image.isNull() == false )
 		{
 			return image;
 		}
 
-		return scaleAndAlignIcon( m_iconDefault, controlInterface->scaledScreenSize() );
+		return scaleAndAlignIcon( m_iconDefault, controlInterface->scaledFramebufferSize() );
 	}
 
 	case ComputerControlInterface::State::ServerNotRunning:
-		return scaleAndAlignIcon( m_iconServerNotRunning, controlInterface->scaledScreenSize() );
+		return scaleAndAlignIcon( m_iconServerNotRunning, controlInterface->scaledFramebufferSize() );
 
 	case ComputerControlInterface::State::AuthenticationFailed:
-		return scaleAndAlignIcon( m_iconConnectionProblem, controlInterface->scaledScreenSize() );
+		return scaleAndAlignIcon( m_iconConnectionProblem, controlInterface->scaledFramebufferSize() );
 
 	default:
 		break;
 	}
 
-	return scaleAndAlignIcon( m_iconDefault, controlInterface->scaledScreenSize() );
+	return scaleAndAlignIcon( m_iconDefault, controlInterface->scaledFramebufferSize() );
 }
 
 
@@ -395,17 +393,20 @@ QImage ComputerControlListModel::computerDecorationRole( const ComputerControlIn
 QString ComputerControlListModel::computerToolTipRole( const ComputerControlInterface::Pointer& controlInterface ) const
 {
 	const QString state( computerStateDescription( controlInterface ) );
+	const QString name( tr( "Name: %1" ).arg( controlInterface->computer().name() ) );
 	const QString location( tr( "Location: %1" ).arg( controlInterface->computer().location() ) );
-	const QString host( tr( "Host/IP address: %1" ).arg( controlInterface->computer().hostAddress() ) );
+	const QString host( tr( "Host/IP address: %1" ).arg( controlInterface->computer().hostAddress().isEmpty()
+															 ? QStringLiteral("&lt;%1&gt;").arg( tr("invalid") )
+															 : controlInterface->computer().hostAddress() ) );
 	const QString user( loggedOnUserInformation( controlInterface ) );
 	const QString features( tr( "Active features: %1" ).arg( activeFeatures( controlInterface ) ) );
 
 	if( user.isEmpty() )
 	{
-		return QStringLiteral( "<b>%1</b><br>%2<br>%3<br>%4" ).arg( state, location, host, features );
+		return QStringLiteral("<b>%1</b><br>%2<br>%3<br>%4<br>%5").arg(state, name, location, host, features);
 	}
 
-	return QStringLiteral( "<b>%1</b><br>%2<br>%3<br>%4<br>%5" ).arg( state, location, host, features, user);
+	return QStringLiteral("<b>%1</b><br>%2<br>%3<br>%4<br>%5<br>%6").arg(state, name, location, host, features, user);
 }
 
 
@@ -508,7 +509,7 @@ QString ComputerControlListModel::loggedOnUserInformation( const ComputerControl
 		auto user = controlInterface->userLoginName();
 		if( controlInterface->userFullName().isEmpty() == false )
 		{
-			user = QStringLiteral( "%1 (%2)" ).arg( user, controlInterface->userFullName() );
+			user = QStringLiteral("%1 (%2)").arg(controlInterface->userFullName(), user);
 		}
 
 		return tr( "Logged on user: %1" ).arg( user );
@@ -522,10 +523,12 @@ QString ComputerControlListModel::loggedOnUserInformation( const ComputerControl
 QString ComputerControlListModel::activeFeatures( const ComputerControlInterface::Pointer& controlInterface ) const
 {
 	QStringList featureNames;
+	featureNames.reserve( controlInterface->activeFeatures().size() );
 
-	for( const auto& feature : m_master->features() )
+	for( const auto& feature : VeyonCore::featureManager().features() )
 	{
-		if( controlInterface->activeFeatures().contains( feature.uid() ) )
+		if( feature.testFlag( Feature::Flag::Master ) &&
+			controlInterface->activeFeatures().contains( feature.uid() ) )
 		{
 			featureNames.append( feature.displayName() );
 		}
@@ -533,5 +536,10 @@ QString ComputerControlListModel::activeFeatures( const ComputerControlInterface
 
 	featureNames.removeAll( {} );
 
+	if( featureNames.isEmpty() )
+	{
+		return tr("[none]");
+	}
+
 	return featureNames.join( QStringLiteral(", ") );
 }
