@@ -141,7 +141,7 @@ bool ComputerManager::saveComputerAndUsersList( const QString& fileName )
 
 
 
-void ComputerManager::updateUser( const ComputerControlInterface::Pointer& controlInterface )
+void ComputerManager::updateUser(const ComputerControlInterface::Pointer& controlInterface) const
 {
 	const auto networkObjectIndex = findNetworkObject( controlInterface->computer().networkObjectUid() );
 
@@ -185,7 +185,11 @@ void ComputerManager::initLocations()
 		vDebug() << "initializing locations for host address" << address.toString();
 	}
 
-	m_currentLocations.append( findLocationOfComputer( m_localHostNames, m_localHostAddresses, QModelIndex() ) );
+	const auto currentLocation = findLocationOfComputer(m_localHostNames, m_localHostAddresses, {});
+	if (currentLocation.isEmpty() == false)
+	{
+		m_currentLocations.append(currentLocation);
+	}
 
 	vDebug() << "found locations" << m_currentLocations;
 
@@ -314,7 +318,8 @@ void ComputerManager::updateLocationFilterList()
 
 
 
-QString ComputerManager::findLocationOfComputer( const QStringList& hostNames, const QList<QHostAddress>& hostAddresses, const QModelIndex& parent )
+QString ComputerManager::findLocationOfComputer(const QStringList& hostNames, const QList<QHostAddress>& hostAddresses,
+												const QModelIndex& parent) const
 {
 	QAbstractItemModel* model = networkObjectModel();
 
@@ -322,13 +327,16 @@ QString ComputerManager::findLocationOfComputer( const QStringList& hostNames, c
 
 	for( int i = 0; i < rows; ++i )
 	{
-		QModelIndex entryIndex = model->index( i, 0, parent );
+		const auto entryIndex = model->index(i, 0, parent);
+		const auto objectType = NetworkObject::Type(model->data(entryIndex, NetworkObjectModel::TypeRole).toInt());
 
-		auto objectType = static_cast<NetworkObject::Type>( model->data( entryIndex, NetworkObjectModel::TypeRole ).toInt() );
-
-		if( objectType == NetworkObject::Type::Location ||
-			objectType == NetworkObject::Type::DesktopGroup )
+		if( NetworkObject::isContainer(objectType) )
 		{
+			if (model->canFetchMore(entryIndex))
+			{
+				model->fetchMore(entryIndex);
+			}
+
 			const auto location = findLocationOfComputer( hostNames, hostAddresses, entryIndex );
 			if( location.isEmpty() == false )
 			{
@@ -353,10 +361,12 @@ QString ComputerManager::findLocationOfComputer( const QStringList& hostNames, c
 
 
 
-ComputerList ComputerManager::getComputersAtLocation( const QString& locationName, const QModelIndex& parent )
+ComputerList ComputerManager::getComputersAtLocation(const QString& locationName, const QModelIndex& parent) const
 {
 	QAbstractItemModel* model = computerTreeModel();
 
+	const bool parentMatches = model->data(parent, NetworkObjectModel::NameRole).toString() == locationName;
+
 	int rows = model->rowCount( parent );
 
 	ComputerList computers;
@@ -364,26 +374,26 @@ ComputerList ComputerManager::getComputersAtLocation( const QString& locationNam
 
 	for( int i = 0; i < rows; ++i )
 	{
-		QModelIndex entryIndex = model->index( i, 0, parent );
+		const auto entryIndex = model->index(i, 0, parent);
+		const auto objectType = NetworkObject::Type(model->data(entryIndex, NetworkObjectModel::TypeRole).toInt());
 
-		auto objectType = static_cast<NetworkObject::Type>( model->data( entryIndex, NetworkObjectModel::TypeRole ).toInt() );
-
-		switch( objectType )
+		if( NetworkObject::isContainer(objectType) )
 		{
-		case NetworkObject::Type::Location:
-		case NetworkObject::Type::DesktopGroup:
-			if( model->data( entryIndex, NetworkObjectModel::NameRole ).toString() == locationName )
+			if (model->data(entryIndex, NetworkObjectModel::NameRole).toString() == locationName ||
+				hasSubLocations(entryIndex))
 			{
 				computers += getComputersAtLocation( locationName, entryIndex );
 			}
-			break;
-		case NetworkObject::Type::Host:
-			computers += Computer( model->data( entryIndex, NetworkObjectModel::UidRole ).toUuid(),
-								   model->data( entryIndex, NetworkObjectModel::NameRole ).toString(),
-								   model->data( entryIndex, NetworkObjectModel::HostAddressRole ).toString(),
-								   model->data( entryIndex, NetworkObjectModel::MacAddressRole ).toString() );
-			break;
-		default: break;
+		}
+		else if( objectType == NetworkObject::Type::Host )
+		{
+			if (parentMatches)
+			{
+				computers += Computer(model->data(entryIndex, NetworkObjectModel::UidRole).toUuid(),
+									  model->data(entryIndex, NetworkObjectModel::NameRole).toString(),
+									  model->data(entryIndex, NetworkObjectModel::HostAddressRole).toString(),
+									  model->data(entryIndex, NetworkObjectModel::MacAddressRole).toString());
+			}
 		}
 	}
 
@@ -392,7 +402,28 @@ ComputerList ComputerManager::getComputersAtLocation( const QString& locationNam
 
 
 
-ComputerList ComputerManager::selectedComputers( const QModelIndex& parent )
+bool ComputerManager::hasSubLocations(const QModelIndex& index) const
+{
+	const auto model = computerTreeModel();
+	const auto rows = model->rowCount(index);
+
+	for (int i = 0; i < rows; ++i)
+	{
+		const auto objectType = NetworkObject::Type(model->data(model->index(i, 0, index),
+																NetworkObjectModel::TypeRole).toInt());
+
+		if (objectType == NetworkObject::Type::Location || objectType == NetworkObject::Type::DesktopGroup)
+		{
+			return true;
+		}
+	}
+
+	return false;
+}
+
+
+
+ComputerList ComputerManager::selectedComputers(const QModelIndex& parent) const
 {
 	QAbstractItemModel* model = computerTreeModel();
 
@@ -409,22 +440,19 @@ ComputerList ComputerManager::selectedComputers( const QModelIndex& parent )
 			continue;
 		}
 
-		auto objectType = static_cast<NetworkObject::Type>( model->data( entryIndex, NetworkObjectModel::TypeRole ).toInt() );
+		const auto objectType = NetworkObject::Type( model->data(entryIndex, NetworkObjectModel::TypeRole).toInt() );
 
-		switch( objectType )
+		if( NetworkObject::isContainer(objectType) )
 		{
-		case NetworkObject::Type::Location:
-		case NetworkObject::Type::DesktopGroup:
 			computers += selectedComputers( entryIndex );
-			break;
-		case NetworkObject::Type::Host:
+		}
+		else if( objectType == NetworkObject::Type::Host )
+		{
 			computers += Computer( model->data( entryIndex, NetworkObjectModel::UidRole ).toUuid(),
 								   model->data( entryIndex, NetworkObjectModel::NameRole ).toString(),
 								   model->data( entryIndex, NetworkObjectModel::HostAddressRole ).toString(),
 								   model->data( entryIndex, NetworkObjectModel::MacAddressRole ).toString(),
 								   model->data( parent, NetworkObjectModel::NameRole ).toString() );
-			break;
-		default: break;
 		}
 	}
 
@@ -433,7 +461,7 @@ ComputerList ComputerManager::selectedComputers( const QModelIndex& parent )
 
 
 
-QModelIndex ComputerManager::findNetworkObject( NetworkObject::Uid networkObjectUid, const QModelIndex& parent )
+QModelIndex ComputerManager::findNetworkObject(NetworkObject::Uid networkObjectUid, const QModelIndex& parent) const
 {
 	QAbstractItemModel* model = networkObjectModel();
 
@@ -443,10 +471,9 @@ QModelIndex ComputerManager::findNetworkObject( NetworkObject::Uid networkObject
 	{
 		QModelIndex entryIndex = model->index( i, 0, parent );
 
-		auto objectType = static_cast<NetworkObject::Type>( model->data( entryIndex, NetworkObjectModel::TypeRole ).toInt() );
+		const auto objectType = NetworkObject::Type( model->data(entryIndex, NetworkObjectModel::TypeRole).toInt() );
 
-		if( objectType == NetworkObject::Type::Location ||
-			objectType == NetworkObject::Type::DesktopGroup )
+		if( NetworkObject::isContainer(objectType) )
 		{
 			QModelIndex index = findNetworkObject( networkObjectUid, entryIndex );
 			if( index.isValid() )
@@ -468,7 +495,7 @@ QModelIndex ComputerManager::findNetworkObject( NetworkObject::Uid networkObject
 
 
 
-QModelIndex ComputerManager::mapToUserNameModelIndex( const QModelIndex& networkObjectIndex )
+QModelIndex ComputerManager::mapToUserNameModelIndex(const QModelIndex& networkObjectIndex) const
 {
 	// map arbitrary index from m_networkObjectModel to username column in m_networkObjectOverlayDataModel
 	const auto parent = m_networkObjectOverlayDataModel->mapFromSource( networkObjectIndex.parent() );
