@@ -1,7 +1,7 @@
 /*
  * ComputerMonitoringModel.cpp - implementation of ComputerMonitoringModel
  *
- * Copyright (c) 2018-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2018-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -22,6 +22,7 @@
  *
  */
 
+#include "ComputerControlListModel.h"
 #include "ComputerMonitoringModel.h"
 
 #if defined(QT_TESTLIB_LIB) && QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
@@ -30,15 +31,14 @@
 
 
 ComputerMonitoringModel::ComputerMonitoringModel( QObject* parent ) :
-	QSortFilterProxyModel( parent ),
-	m_stateRole( -1 ),
-	m_stateFilter( ComputerControlInterface::State::None )
+	QSortFilterProxyModel( parent )
 {
 #if defined(QT_TESTLIB_LIB) && QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
 	new QAbstractItemModelTester( this, QAbstractItemModelTester::FailureReportingMode::Warning, this );
 #endif
 
 	setFilterCaseSensitivity( Qt::CaseInsensitive );
+	setUserLoginNameRole( ComputerControlListModel::UserLoginNameRole );
 }
 
 
@@ -52,6 +52,15 @@ void ComputerMonitoringModel::setStateRole( int role )
 
 
 
+void ComputerMonitoringModel::setUserLoginNameRole( int role )
+{
+	beginResetModel();
+	m_userLoginNameRole = role;
+	endResetModel();
+}
+
+
+
 void ComputerMonitoringModel::setStateFilter( ComputerControlInterface::State state )
 {
 	beginResetModel();
@@ -61,6 +70,18 @@ void ComputerMonitoringModel::setStateFilter( ComputerControlInterface::State st
 
 
 
+void ComputerMonitoringModel::setFilterNonEmptyUserLoginNames( bool enabled )
+{
+	if( enabled != m_filterNonEmptyUserLoginNames )
+	{
+		beginResetModel();
+		m_filterNonEmptyUserLoginNames = enabled;
+		endResetModel();
+	}
+}
+
+
+
 bool ComputerMonitoringModel::filterAcceptsRow( int sourceRow, const QModelIndex& sourceParent ) const
 {
 	if( m_stateFilter != ComputerControlInterface::State::None &&
@@ -71,5 +92,13 @@ bool ComputerMonitoringModel::filterAcceptsRow( int sourceRow, const QModelIndex
 		return false;
 	}
 
+	if( m_filterNonEmptyUserLoginNames &&
+		userLoginNameRole() >= 0 &&
+		sourceModel()->data( sourceModel()->index( sourceRow, 0, sourceParent ),
+							 m_userLoginNameRole ).toString().isEmpty() )
+	{
+		return false;
+	}
+
 	return QSortFilterProxyModel::filterAcceptsRow( sourceRow, sourceParent );
 }
