@@ -1,7 +1,7 @@
 /*
  * ComputerMonitoringModel.h - header file for ComputerMonitoringModel
  *
- * Copyright (c) 2018-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2018-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -41,6 +41,13 @@ public:
 
 	void setStateRole( int role );
 
+	int userLoginNameRole() const
+	{
+		return m_userLoginNameRole;
+	}
+
+	void setUserLoginNameRole( int role );
+
 	ComputerControlInterface::State stateFilter() const
 	{
 		return m_stateFilter;
@@ -48,11 +55,20 @@ public:
 
 	void setStateFilter( ComputerControlInterface::State state );
 
+	bool filterNonEmptyUserLoginNames() const
+	{
+		return m_filterNonEmptyUserLoginNames;
+	}
+
+	void setFilterNonEmptyUserLoginNames( bool enabled );
+
 protected:
 	bool filterAcceptsRow( int sourceRow, const QModelIndex& sourceParent ) const override;
 
 private:
-	int m_stateRole;
-	ComputerControlInterface::State m_stateFilter;
+	int m_stateRole{-1};
+	int m_userLoginNameRole{-1};
+	ComputerControlInterface::State m_stateFilter{ComputerControlInterface::State::None};
+	bool m_filterNonEmptyUserLoginNames{false};
 
 };
