@@ -1,7 +1,7 @@
 /*
  * ComputerSelectPanel.cpp - provides a view for a network object tree
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -45,6 +45,9 @@ ComputerSelectPanel::ComputerSelectPanel( ComputerManager& computerManager, QWid
 	m_filterProxyModel->setSourceModel( computerManager.computerTreeModel() );
 	m_filterProxyModel->setFilterCaseSensitivity( Qt::CaseInsensitive );
 	m_filterProxyModel->setFilterKeyColumn( -1 ); // filter all columns instead of first one only
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+	m_filterProxyModel->setRecursiveFilteringEnabled(true);
+#endif
 
 	ui->setupUi(this);
 
