@@ -1,7 +1,7 @@
 /*
  * RecursiveFilterProxyModel.cpp - proxy model for recursive filtering
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -24,14 +24,9 @@
 
 #include "RecursiveFilterProxyModel.h"
 
-#if defined(QT_TESTLIB_LIB) && QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
-#include <QAbstractItemModelTester>
-#endif
-
+#if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
 RecursiveFilterProxyModel::RecursiveFilterProxyModel( QObject* parent ) :
-	KRecursiveFilterProxyModel( parent )
+    KRecursiveFilterProxyModel( parent )
 {
-#if defined(QT_TESTLIB_LIB) && QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
-	new QAbstractItemModelTester( this, QAbstractItemModelTester::FailureReportingMode::Warning, this );
-#endif
 }
+#endif
