@@ -1,7 +1,7 @@
 /*
  * RecursiveFilterProxyModel.h - proxy model for recursive filtering
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -24,11 +24,21 @@
 
 #pragma once
 
-#include "krecursivefilterproxymodel.h"
+#include <QSortFilterProxyModel>
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+
+using RecursiveFilterProxyModel = QSortFilterProxyModel;
+
+#else
+
+#include "KRecursiveFilterProxyModel.h"
 
 class RecursiveFilterProxyModel : public KRecursiveFilterProxyModel
 {
 public:
-	explicit RecursiveFilterProxyModel( QObject* parent );
+    explicit RecursiveFilterProxyModel( QObject* parent );
 
 };
+
+#endif
