@@ -1,7 +1,7 @@
 /*
  * SpotlightModel.cpp - implementation of SpotlightModel
  *
- * Copyright (c) 2020-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2020-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -46,7 +46,7 @@ void SpotlightModel::setUpdateInRealtime( bool enabled )
 {
 	m_updateInRealtime = enabled;
 
-	for( const auto& controlInterface : m_controlInterfaces )
+	for( const auto& controlInterface : qAsConst(m_controlInterfaces) )
 	{
 		controlInterface->setUpdateMode( m_updateInRealtime
 											 ? ComputerControlInterface::UpdateMode::Live
@@ -90,13 +90,13 @@ QVariant SpotlightModel::data( const QModelIndex& index, int role ) const
 
 	if( role == Qt::DecorationRole )
 	{
-		auto screen = sourceModel()->data( sourceIndex, ComputerListModel::ScreenRole ).value<QImage>();
-		if( screen.isNull() )
+		auto framebuffer = sourceModel()->data(sourceIndex, ComputerListModel::FramebufferRole).value<QImage>();
+		if (framebuffer.isNull())
 		{
-			screen = sourceModel()->data( sourceIndex, Qt::DecorationRole ).value<QImage>();
+			framebuffer = sourceModel()->data(sourceIndex, Qt::DecorationRole).value<QImage>();
 		}
 
-		return screen.scaled( m_iconSize, Qt::KeepAspectRatio, Qt::SmoothTransformation );
+		return framebuffer.scaled(m_iconSize, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 	}
 
 	return QSortFilterProxyModel::data( index, role );
