@@ -1,7 +1,7 @@
 /*
  * SpotlightModel.h - header file for SpotlightModel
  *
- * Copyright (c) 2020-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2020-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -49,7 +49,7 @@ protected:
 
 private:
 	QSize m_iconSize;
-	bool m_updateInRealtime;
+	bool m_updateInRealtime{false};
 
 	ComputerControlInterfaceList m_controlInterfaces;
 
