@@ -1,7 +1,7 @@
 /*
  * SpotlightPanel.cpp - implementation of SpotlightPanel
  *
- * Copyright (c) 2020-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2020-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -158,7 +158,7 @@ void SpotlightPanel::updateIconSize()
 
 void SpotlightPanel::addPressedItem( const QModelIndex& index )
 {
-	if( QGuiApplication::mouseButtons().testFlag( Qt::MidButton ) )
+	if( QGuiApplication::mouseButtons().testFlag( Qt::MiddleButton ) )
 	{
 		m_globalComputerMonitoringWidget->selectionModel()->select( index, QItemSelectionModel::SelectCurrent );
 
@@ -170,7 +170,7 @@ void SpotlightPanel::addPressedItem( const QModelIndex& index )
 
 void SpotlightPanel::removePressedItem( const QModelIndex& index )
 {
-	if( QGuiApplication::mouseButtons().testFlag( Qt::MidButton ) )
+	if( QGuiApplication::mouseButtons().testFlag( Qt::MiddleButton ) )
 	{
 		ui->monitoringWidget->selectionModel()->select( index, QItemSelectionModel::SelectCurrent );
 
