@@ -1,7 +1,7 @@
 /*
  * AuthKeysPlugin.cpp - implementation of AuthKeysPlugin class
  *
- * Copyright (c) 2018-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2018-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -22,6 +22,8 @@
  *
  */
 
+#include <QFileInfo>
+
 #include "AuthKeysConfigurationPage.h"
 #include "AuthKeysPlugin.h"
 #include "AuthKeysManager.h"
@@ -67,6 +69,11 @@ ConfigurationPage* AuthKeysPlugin::createConfigurationPage()
 CommandLinePluginInterface::RunResult AuthKeysPlugin::handle_help( const QStringList& arguments )
 {
 	const auto command = arguments.value( 0 );
+	if( command.isEmpty() )
+	{
+		error( tr("Please specify the command to display help for.") );
+		return NoResult;
+	}
 
 	const QMap<QString, QStringList> commands = {
 		{ QStringLiteral("create"),
@@ -110,9 +117,9 @@ CommandLinePluginInterface::RunResult AuthKeysPlugin::handle_help( const QString
 		return NoResult;
 	}
 
-	print( tr("Please specify the command to display help for!") );
+	error( tr("The specified command does not exist or no help is available for it.") );
 
-	return Unknown;
+	return NoResult;
 }
 
 
@@ -230,6 +237,12 @@ CommandLinePluginInterface::RunResult AuthKeysPlugin::handle_import( const QStri
 		return NotEnoughArguments;
 	}
 
+	if( QFileInfo::exists( arguments[0] ) )
+	{
+		error( tr( "Please specify the key name (e.g. \"teacher/public\") as the first argument." ) );
+		return InvalidArguments;
+	}
+
 	const auto nameAndType = arguments[0].split( QLatin1Char('/') );
 	const auto name = nameAndType.value( 0 );
 	const auto type = nameAndType.value( 1 );
