@@ -1,7 +1,7 @@
 /*
  * BuiltinDirectoryPlugin.cpp - implementation of BuiltinDirectoryPlugin class
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -23,6 +23,7 @@
  */
 
 #include <QFile>
+#include <QRegularExpression>
 
 #include "BuiltinDirectoryConfigurationPage.h"
 #include "BuiltinDirectory.h"
@@ -178,7 +179,9 @@ CommandLinePluginInterface::RunResult BuiltinDirectoryPlugin::handle_help( const
 		return NoResult;
 	}
 
-	return Unknown;
+	error( tr("The specified command does not exist or no help is available for it.") );
+
+	return NoResult;
 }
 
 
@@ -667,13 +670,14 @@ bool BuiltinDirectoryPlugin::exportFile( QFile& outputFile, const QString& forma
 NetworkObject BuiltinDirectoryPlugin::findNetworkObject( const QString& uidOrName ) const
 {
 	const ObjectManager<NetworkObject> objectManager( m_configuration.networkObjects() );
+	const QUuid uid{uidOrName};
 
-	if( QUuid( uidOrName ).isNull() )
+	if( uid.isNull() )
 	{
 		return objectManager.findByName( uidOrName );
 	}
 
-	return objectManager.findByUid( uidOrName );
+	return objectManager.findByUid( uid );
 }
 
 
@@ -682,13 +686,11 @@ NetworkObject BuiltinDirectoryPlugin::toNetworkObject( const QString& line, cons
 													   QString& location )
 {
 	QStringList placeholders;
-	QRegExp varDetectionRX( QStringLiteral("\\((%\\w+%):[^)]+\\)") );
-	int pos = 0;
+	auto varDetectionMatchIterator = QRegularExpression{ QStringLiteral("\\((%\\w+%):[^)]+\\)") }.globalMatch( regExWithPlaceholders );
 
-	while( ( pos = varDetectionRX.indexIn( regExWithPlaceholders, pos ) ) != -1 )
+	while( varDetectionMatchIterator.hasNext() )
 	{
-		placeholders.append( varDetectionRX.cap(1) );
-		pos += varDetectionRX.matchedLength();
+		placeholders.append( varDetectionMatchIterator.next().captured(1) );
 	}
 
 	QString rxString = regExWithPlaceholders;
@@ -697,14 +699,14 @@ NetworkObject BuiltinDirectoryPlugin::toNetworkObject( const QString& line, cons
 		rxString.replace( QStringLiteral("%1:").arg( var ), QString() );
 	}
 
-	QRegExp rx( rxString );
-	if( rx.indexIn( line ) != -1 )
+	auto match = QRegularExpression( rxString ).match( line );
+	if( match.hasMatch() )
 	{
 		auto objectType = NetworkObject::Type::Host;
 		const auto typeIndex = placeholders.indexOf( QStringLiteral("%type%") );
 		if( typeIndex != -1 )
 		{
-			objectType = parseNetworkObjectType( rx.cap( 1 + typeIndex ) );
+			objectType = parseNetworkObjectType( match.captured( 1 + typeIndex ) );
 		}
 
 		const auto locationIndex = placeholders.indexOf( QStringLiteral("%location%") );
@@ -712,9 +714,9 @@ NetworkObject BuiltinDirectoryPlugin::toNetworkObject( const QString& line, cons
 		const auto hostIndex = placeholders.indexOf( QStringLiteral("%host%") );
 		const auto macIndex = placeholders.indexOf( QStringLiteral("%mac%") );
 
-		auto name = ( nameIndex != -1 ) ? rx.cap( 1 + nameIndex ).trimmed() : QString();
-		auto host = ( hostIndex != -1 ) ? rx.cap( 1 + hostIndex ).trimmed() : QString();
-		auto mac = ( macIndex != -1 ) ? rx.cap( 1 + macIndex ).trimmed() : QString();
+		auto name = ( nameIndex != -1 ) ? match.captured( 1 + nameIndex ).trimmed() : QString();
+		auto host = ( hostIndex != -1 ) ? match.captured( 1 + hostIndex ).trimmed() : QString();
+		auto mac = ( macIndex != -1 ) ? match.captured( 1 + macIndex ).trimmed() : QString();
 
 		if( objectType == NetworkObject::Type::Location )
 		{
@@ -723,7 +725,7 @@ NetworkObject BuiltinDirectoryPlugin::toNetworkObject( const QString& line, cons
 
 		if( location.isEmpty() && locationIndex != -1 )
 		{
-			location = rx.cap( 1 + locationIndex ).trimmed();
+			location = match.captured( 1 + locationIndex ).trimmed();
 		}
 
 		if( host.isEmpty() )
