@@ -1,7 +1,7 @@
 /*
  * BuiltinDirectoryPlugin.h - declaration of BuiltinDirectoryPlugin class
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -52,7 +52,7 @@ public:
 
 	Plugin::Uid uid() const override
 	{
-		return QStringLiteral("14bacaaa-ebe5-449c-b881-5b382f952571");
+		return Plugin::Uid{ QStringLiteral("14bacaaa-ebe5-449c-b881-5b382f952571") };
 	}
 
 	QVersionNumber version() const override
