@@ -1,7 +1,7 @@
 /*
  * DemoClient.h - client for demo server
  *
- * Copyright (c) 2006-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -26,20 +26,27 @@
 
 #include <QObject>
 
+#include "ComputerControlInterface.h"
+
 class VncViewWidget;
 
 class DemoClient : public QObject
 {
 	Q_OBJECT
 public:
-	DemoClient( const QString& host, int port, bool fullscreen, const QRect& viewport, QObject* parent = nullptr );
+	DemoClient( const QString& host, int port, bool fullscreen, QRect viewport, QObject* parent = nullptr );
 	~DemoClient() override;
 
+protected:
+	bool eventFilter(QObject* watched, QEvent* event) override;
+
 private:
 	void viewDestroyed( QObject* obj );
 	void resizeToplevelWidget();
 
-	QWidget* m_toplevel;
-	VncViewWidget* m_vncView;
+	QWidget* m_toplevel{nullptr};
+
+	ComputerControlInterface::Pointer m_computerControlInterface;
+	VncViewWidget* m_vncView{nullptr};
 
 } ;
