@@ -144,24 +144,25 @@ bool DemoFeaturePlugin::controlFeature( Feature::Uid featureUid,
 {
 	if( featureUid == m_demoServerFeature.uid() )
 	{
-		m_demoServerArguments = arguments;
-
 		if( operation == Operation::Start )
 		{
-			m_demoServerControlTimer.start( DemoServerControlInterval );
+			m_demoServerArguments = arguments;
 			m_demoServerControlInterfaces = computerControlInterfaces;
+			m_demoServerControlTimer.start( DemoServerControlInterval );
+			controlDemoServer();
 		}
 		else if( operation == Operation::Stop )
 		{
 			m_demoServerControlTimer.stop();
+			m_demoServerControlInterfaces = computerControlInterfaces;
+			controlDemoServer();
+			m_demoServerControlInterfaces.clear();
 		}
 		else
 		{
 			return false;
 		}
 
-		controlDemoServer();
-
 		return true;
 	}
 
@@ -563,7 +564,7 @@ QRect DemoFeaturePlugin::viewportFromScreenSelection() const
 
 
 
-bool DemoFeaturePlugin::controlDemoServer()
+void DemoFeaturePlugin::controlDemoServer()
 {
 	if( m_demoServerControlTimer.isActive() )
 	{
@@ -585,8 +586,6 @@ bool DemoFeaturePlugin::controlDemoServer()
 		sendFeatureMessage( FeatureMessage{ m_demoServerFeature.uid(), StopDemoServer },
 							m_demoServerControlInterfaces );
 	}
-
-	return true;
 }
 
 
