@@ -2,7 +2,7 @@
  * DemoServer.h - multi-threaded slim VNC-server for demo-purposes (optimized
  *                for lot of clients accessing server in read-only-mode)
  *
- * Copyright (c) 2006-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -48,6 +48,8 @@ public:
 				const DemoConfiguration& configuration, int demoServerPort, QObject *parent );
 	~DemoServer() override;
 
+	void terminate();
+
 	const DemoConfiguration& configuration() const
 	{
 		return m_configuration;
@@ -89,6 +91,7 @@ private:
 	bool setVncServerEncodings();
 
 	static constexpr auto ConnectionThreadWaitTime = 5000;
+	static constexpr auto TerminateRetryInterval = 1000;
 
 	const DemoConfiguration& m_configuration;
 	const qint64 m_memoryLimit;
