@@ -2,7 +2,7 @@
  * DemoServer.cpp - multi-threaded slim VNC-server for demo-purposes (optimized
  *                   for lot of clients accessing server in read-only-mode)
  *
- * Copyright (c) 2006-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -30,12 +30,13 @@
 #include "DemoConfiguration.h"
 #include "DemoServer.h"
 #include "DemoServerConnection.h"
+#include "FeatureMessage.h"
 
 
 DemoServerConnection::DemoServerConnection( DemoServer* demoServer,
 											const Password& demoAccessToken,
 											quintptr socketDescriptor ) :
-	QThread(),
+	QThread( demoServer ),
 	m_demoAccessToken( demoAccessToken ),
 	m_demoServer( demoServer ),
 	m_socketDescriptor( socketDescriptor ),
@@ -101,7 +102,7 @@ void DemoServerConnection::processClient()
 		// try again later in case we could not proceed because of
 		// external protocol dependencies or in case we're finished
 		// and already have RFB messages in receive queue
-		QTimer::singleShot( ProtocolRetryTime, [this]() { processClient(); } );
+		QTimer::singleShot( ProtocolRetryTime, m_socket, [this]() { processClient(); } );
 	}
 	else
 	{
@@ -138,6 +139,18 @@ bool DemoServerConnection::receiveClientMessage()
 		}
 		break;
 
+	case FeatureMessage::RfbMessageType:
+	{
+		FeatureMessage featureMessage;
+		m_socket->getChar(nullptr);
+		if( featureMessage.isReadyForReceive(m_socket) && featureMessage.receive(m_socket) )
+		{
+			return true;
+		}
+		m_socket->ungetChar(messageType);
+		break;
+	}
+
 	default:
 		if( m_rfbClientToServerMessageSizes.contains( messageType ) == false )
 		{
@@ -183,9 +196,10 @@ void DemoServerConnection::sendFramebufferUpdate()
 	}
 
 	bool sentUpdates = false;
-	for( ; m_framebufferUpdateMessageIndex < framebufferUpdateMessageCount; ++m_framebufferUpdateMessageIndex )
+	while( m_framebufferUpdateMessageIndex < framebufferUpdateMessageCount )
 	{
 		m_socket->write( framebufferUpdateMessages[m_framebufferUpdateMessageIndex] );
+		++m_framebufferUpdateMessageIndex;
 		sentUpdates = true;
 	}
 
@@ -194,6 +208,6 @@ void DemoServerConnection::sendFramebufferUpdate()
 	if( sentUpdates == false )
 	{
 		// did not send updates but client still waiting for update? then try again soon
-		QTimer::singleShot( m_framebufferUpdateInterval, [this]() { sendFramebufferUpdate(); } );
+		QTimer::singleShot( m_framebufferUpdateInterval, m_socket, [this]() { sendFramebufferUpdate(); } );
 	}
 }
