@@ -1,7 +1,7 @@
 /*
  * DesktopServiceObject.h - data class representing a desktop service object
  *
- * Copyright (c) 2018-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2018-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -39,7 +39,7 @@ public:
 	enum class Type
 	{
 		None,
-		Program,
+		Application,
 		Website,
 	} ;
 
