@@ -1,7 +1,7 @@
 /*
  * DesktopServicesFeaturePlugin.h - declaration of DesktopServicesFeaturePlugin class
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -41,7 +41,7 @@ class DesktopServicesFeaturePlugin : public QObject, PluginInterface,
 public:
 	enum class Argument
 	{
-		Programs,
+		Applications,
 		WebsiteUrl
 	};
 	Q_ENUM(Argument)
@@ -51,12 +51,12 @@ public:
 
 	Plugin::Uid uid() const override
 	{
-		return QStringLiteral("a54ee018-42bf-4569-90c7-0d8470125ccf");
+		return Plugin::Uid{ QStringLiteral("a54ee018-42bf-4569-90c7-0d8470125ccf") };
 	}
 
 	QVersionNumber version() const override
 	{
-		return QVersionNumber( 1, 1 );
+		return QVersionNumber( 2, 0 );
 	}
 
 	QString name() const override
@@ -66,7 +66,7 @@ public:
 
 	QString description() const override
 	{
-		return tr( "Start programs and services in user desktop" );
+		return tr( "Start apps and open websites in user sessions" );
 	}
 
 	QString vendor() const override
@@ -79,6 +79,8 @@ public:
 		return QStringLiteral("Tobias Junghans");
 	}
 
+	void upgrade( const QVersionNumber& oldVersion ) override;
+
 	const FeatureList& featureList() const override
 	{
 		return m_features;
@@ -98,36 +100,47 @@ public:
 
 	ConfigurationPage* createConfigurationPage() override;
 
+Q_SIGNALS:
+	Q_INVOKABLE void acceptStartAppDialog( const QString& app, const QString& saveItemName );
+	Q_INVOKABLE void acceptOpenWebsiteDialog( const QString& website, const QString& saveItemName );
+
 private:
 	bool eventFilter( QObject* object, QEvent* event ) override;
 
 	void updateFeatures();
 	void openMenu( const QString& objectName );
 
-	void runProgram( VeyonMasterInterface& master, const ComputerControlInterfaceList& computerControlInterfaces );
-	void openWebsite( VeyonMasterInterface& master, const ComputerControlInterfaceList& computerControlInterfaces );
+	void executeStartAppDialog( VeyonMasterInterface& master,
+							 const ComputerControlInterfaceList& computerControlInterfaces );
+	void startApp( const QString& app, const QString& saveItemName,
+				  VeyonMasterInterface& master, const ComputerControlInterfaceList& computerControlInterfaces );
 
-	void runProgramAsUser( const QString& commandLine );
+	void executeOpenWebsiteDialog( VeyonMasterInterface& master,
+								  const ComputerControlInterfaceList& computerControlInterfaces );
+	void openWebsite( const QString& website, const QString& saveItemName,
+					 VeyonMasterInterface& master, const ComputerControlInterfaceList& computerControlInterfaces );
+
+	void runApplicationAsUser( const QString& commandLine );
 	bool openWebsite( const QString& urlString );
 
-	void updatePredefinedPrograms();
+	void updatePredefinedApplications();
 	void updatePredefinedWebsites();
 
-	void updatePredefinedProgramFeatures();
+	void updatePredefinedApplicationFeatures();
 	void updatePredefinedWebsiteFeatures();
 
 	QString predefinedServicePath( Feature::Uid subFeatureUid ) const;
 
 	DesktopServicesConfiguration m_configuration;
 
-	QJsonArray m_predefinedPrograms;
+	QJsonArray m_predefinedApps;
 	QJsonArray m_predefinedWebsites;
 
-	const Feature m_runProgramFeature;
+	const Feature m_startAppFeature;
 	const Feature m_openWebsiteFeature;
 
-	FeatureList m_predefinedProgramsFeatures;
-	FeatureList m_predefinedWebsitesFeatures;
+	FeatureList m_predefinedAppsFeatures{};
+	FeatureList m_predefinedWebsitesFeatures{};
 
 	FeatureList m_features;
 
