@@ -1,7 +1,7 @@
 /*
  * FileTransferPlugin.h - declaration of FileTransferPlugin class
  *
- * Copyright (c) 2018-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2018-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -56,7 +56,7 @@ public:
 
 	Plugin::Uid uid() const override
 	{
-		return QStringLiteral("d4bb9c42-9eef-4ecb-8dd5-dfd84b355481");
+		return Plugin::Uid{ QStringLiteral("d4bb9c42-9eef-4ecb-8dd5-dfd84b355481") };
 	}
 
 	QVersionNumber version() const override
