@@ -1,7 +1,7 @@
 /*
  * PlatformSessionManager.h - declaration of PlatformSessionManager class
  *
- * Copyright (c) 2018-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2018-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -35,7 +35,16 @@ class QLocalSocket;
 
 class PlatformSessionManager : public QThread
 {
+	Q_OBJECT
 public:
+	enum class Mode
+	{
+		Local,
+		Active,
+		Multi
+	};
+	Q_ENUM(Mode)
+
 	using SessionId = PlatformSessionFunctions::SessionId;
 	using PlatformSessionId = QString;
 
@@ -47,9 +56,14 @@ public:
 
 	static SessionId resolveSessionId( const PlatformSessionId& platformSessionId );
 
-	bool multiSession() const
+	Mode mode() const
 	{
-		return m_multiSession;
+		return m_mode;
+	}
+
+	int maximumSessionCount() const
+	{
+		return m_maximumSessionCount;
 	}
 
 	using SessionMap = QMap<PlatformSessionId, SessionId>;
@@ -69,7 +83,7 @@ private:
 
 	static bool waitForMessage( QLocalSocket* socket );
 
-	const bool m_multiSession;
+	const Mode m_mode;
 	const int m_maximumSessionCount;
 
 	QMutex m_mutex;
