@@ -33,7 +33,9 @@
 
 #include <unistd.h>
 #include <grp.h>
+#ifdef HAVE_LIBPROCPS
 #include <proc/readproc.h>
+#endif
 
 #include "LinuxCoreFunctions.h"
 #include "LinuxDesktopIntegration.h"
@@ -228,66 +230,59 @@ bool LinuxCoreFunctions::runProgramAsUser( const QString& program, const QString
 	Q_UNUSED(desktop);
 
 	const auto uid = LinuxUserFunctions::userIdFromName( username );
-	if( uid <= 0 )
+	if( uid < 0 )
 	{
+		vCritical() << "failed to resolve uid from username" << username;
 		return false;
 	}
 
 	const auto gid = LinuxUserFunctions::userGroupIdFromName( username );
-	if( gid <= 0 )
+	if( gid < 0 )
 	{
+		vCritical() << "failed to resolve gid from username" << username;
 		return false;
 	}
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-	auto process = new QProcess;
-	process->setChildProcessModifier( [uid, gid]() {
-		if( setgroups(0, nullptr) != 0 )
+	const auto adjustChildProcessPrivileges = [uid, gid]()
+	{
+		const auto isRoot = getuid() == 0 || geteuid() == 0;
+		if (setgroups(0, nullptr) != 0 && isRoot)
 		{
 			qFatal( "Could not drop all supplementary groups for child process!" );
 		}
-		if( setgid( gid ) != 0 )
+		if (setgid(gid) != 0 && isRoot)
 		{
 			qFatal( "Could not set GID for child process!" );
 		}
-		if( setuid( uid ) != 0 )
+		if (setuid(uid) != 0 && isRoot)
 		{
 			qFatal( "Could not set UID for child process!" );
 		}
-	} );
+	};
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+	auto process = new QProcess;
+	process->setChildProcessModifier(adjustChildProcessPrivileges);
 #else
 	class UserProcess : public QProcess // clazy:exclude=missing-qobject-macro
 	{
 	public:
-		explicit UserProcess( uid_t uid, gid_t gid, QObject* parent = nullptr ) :
+		explicit UserProcess(const std::function<void()>& modifier, QObject* parent = nullptr) :
 			QProcess( parent ),
-			m_uid( uid ),
-			m_gid( gid )
+			m_modifier(modifier)
 		{
 		}
 
 		void setupChildProcess() override
 		{
-			if( setgroups( 0, nullptr ) != 0 )
-			{
-				qFatal( "Could not drop all supplementary groups for child process!" );
-			}
-			if( setgid( m_gid ) != 0 )
-			{
-				qFatal( "Could not set GID for child process!" );
-			}
-			if( setuid( m_uid ) != 0 )
-			{
-				qFatal( "Could not set UID for child process!" );
-			}
+			m_modifier();
 		}
 
 	private:
-		const uid_t m_uid;
-		const uid_t m_gid;
+		const std::function<void ()>& m_modifier;
 	};
 
-	auto process = new UserProcess( uid, gid );
+	auto process = new UserProcess(adjustChildProcessPrivileges);
 #endif
 
 	QObject::connect( process, QOverload<int, QProcess::ExitStatus>::of( &QProcess::finished ), &QProcess::deleteLater );
@@ -444,6 +439,7 @@ void LinuxCoreFunctions::restartDisplayManagers()
 
 
 
+#ifdef HAVE_LIBPROCPS
 void LinuxCoreFunctions::forEachChildProcess( const std::function<bool(proc_t*)>& visitor,
 											 int parentPid, int flags, bool visitParent )
 {
@@ -473,7 +469,47 @@ void LinuxCoreFunctions::forEachChildProcess( const std::function<bool(proc_t*)>
 
 	closeproc( proc );
 }
+#elif defined(HAVE_LIBPROC2)
+void LinuxCoreFunctions::forEachChildProcess(const std::function<bool(const pids_stack*, const pids_info*)>& visitor,
+											 int parentPid, const std::vector<pids_item>& items, bool visitParent)
+{
+	QProcessEnvironment sessionEnv;
 
+	pids_info* info = nullptr;
+	pids_stack* stack;
+	QList<int> ppids;
+
+	std::vector<pids_item> allItems{PIDS_ID_PID, PIDS_ID_PPID};
+	static constexpr auto PidItemIndex = 0;
+	static constexpr auto PPidItemIndex = 1;
+
+	allItems.insert(allItems.end(), items.cbegin(), items.cend());
+
+	if (procps_pids_new(&info, allItems.data(), allItems.size()) < 0)
+	{
+		return;
+	}
+
+	while ((stack = procps_pids_get(info, PIDS_FETCH_TASKS_ONLY)))
+	{
+		const auto ppid = PIDS_VAL(PPidItemIndex, s_int, stack, info);
+
+		if (ppid == parentPid)
+		{
+			if (visitParent == false || visitor(stack, info))
+			{
+				ppids.append(PIDS_VAL(PidItemIndex, s_int, stack, info));
+			}
+		}
+		else if (ppids.contains(ppid) && visitor(stack, info))
+		{
+			ppids.append(PIDS_VAL(PidItemIndex, s_int, stack, info));
+		}
+	}
+
+	procps_pids_unref(&info);
+}
+#endif
 
 
 bool LinuxCoreFunctions::waitForProcess( qint64 pid, int timeout, int sleepInterval )
