@@ -1,7 +1,7 @@
 /*
  * LinuxFilesystemFunctions.cpp - implementation of LinuxFilesystemFunctions class
  *
- * Copyright (c) 2018-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2018-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -163,7 +163,7 @@ bool LinuxFilesystemFunctions::openFileSafely( QFile* file, QIODevice::OpenMode
 		return false;
 	}
 
-	struct stat s;
+	struct stat s{};
 	if( fstat(fd, &s) != 0 )
 	{
 		close(fd);
