@@ -1,7 +1,7 @@
 /*
  * LinuxServiceCore.h - declaration of LinuxServiceCore class
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -28,7 +28,7 @@
 #include "PlatformSessionManager.h"
 #include "ServiceDataManager.h"
 
-class QProcess;
+class LinuxServerProcess;
 
 // clazy:excludeall=copyable-polymorphic
 
@@ -47,23 +47,21 @@ private Q_SLOTS:
 
 private:
 	static constexpr auto LoginManagerReconnectInterval = 3000;
-	static constexpr auto ServerShutdownTimeout = 1000;
-	static constexpr auto ServerTerminateTimeout = 3000;
-	static constexpr auto ServerKillTimeout = 10000;
-	static constexpr auto ServerWaitSleepInterval = 100;
 	static constexpr auto SessionEnvironmentProbingInterval = 1000;
 	static constexpr auto SessionStateProbingInterval = 1000;
-	static constexpr auto SessionUptimeSecondsMinimum = 3;
-	static constexpr auto SessionUptimeProbingInterval = 1000;
 
 	void connectToLoginManager();
+	void startServers();
+	void startServer( const QString& sessionPath );
+	void deferServerStart( const QString& sessionPath, int delay );
 	void stopServer( const QString& sessionPath );
 	void stopAllServers();
 
-	QStringList listSessions();
+	void checkSessionState( const QString& sessionPath );
 
 	LinuxCoreFunctions::DBusInterfacePointer m_loginManager{LinuxCoreFunctions::systemdLoginManager()};
-	QMap<QString, QProcess *> m_serverProcesses;
+	QMap<QString, LinuxServerProcess *> m_serverProcesses;
+	QStringList m_deferredServerSessions;
 
 	ServiceDataManager m_dataManager{};
 	PlatformSessionManager m_sessionManager{};
