@@ -431,9 +431,11 @@ uid_t LinuxUserFunctions::userIdFromName( const QString& username )
 		return pw_entry->pw_uid;
 	}
 
-	return 0;
+	return -1;
 }
 
+
+
 gid_t LinuxUserFunctions::userGroupIdFromName( const QString& username )
 {
 	const auto pw_entry = getpwnam( username.toUtf8().constData() );
@@ -443,7 +445,7 @@ gid_t LinuxUserFunctions::userGroupIdFromName( const QString& username )
 		return pw_entry->pw_gid;
 	}
 
-	return 0;
+	return -1;
 }
 
 
