@@ -1,7 +1,7 @@
 /*
  * PowerControlFeaturePlugin.cpp - implementation of PowerControlFeaturePlugin class
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -22,6 +22,7 @@
  *
  */
 
+#include <QEvent>
 #include <QMessageBox>
 #include <QNetworkInterface>
 #include <QProgressBar>
@@ -46,7 +47,7 @@ PowerControlFeaturePlugin::PowerControlFeaturePlugin( QObject* parent ) :
 { QStringLiteral("on"), tr( "Power on a computer via Wake-on-LAN (WOL)" ) },
 				} ),
 	m_powerOnFeature( QStringLiteral( "PowerOn" ),
-					  Feature::Action | Feature::AllComponents,
+					  Feature::Flag::Action | Feature::Flag::AllComponents,
 					  Feature::Uid( "f483c659-b5e7-4dbc-bd91-2c9403e70ebd" ),
 					  Feature::Uid(),
 					  tr( "Power on" ), {},
@@ -54,14 +55,14 @@ PowerControlFeaturePlugin::PowerControlFeaturePlugin( QObject* parent ) :
 						  "This way you do not have to power on each computer by hand." ),
 					  QStringLiteral(":/powercontrol/preferences-system-power-management.png") ),
 	m_rebootFeature( QStringLiteral( "Reboot" ),
-					 Feature::Action | Feature::AllComponents,
+					 Feature::Flag::Action | Feature::Flag::AllComponents,
 					 Feature::Uid( "4f7d98f0-395a-4fff-b968-e49b8d0f748c" ),
 					 Feature::Uid(),
 					 tr( "Reboot" ), {},
 					 tr( "Click this button to reboot all computers." ),
 					 QStringLiteral(":/powercontrol/system-reboot.png") ),
 	m_powerDownFeature( QStringLiteral( "PowerDown" ),
-						Feature::Action | Feature::AllComponents,
+						Feature::Flag::Action | Feature::Flag::AllComponents,
 						Feature::Uid( "6f5a27a0-0e2f-496e-afcc-7aae62eede10" ),
 						Feature::Uid(),
 						tr( "Power down" ), {},
@@ -69,22 +70,22 @@ PowerControlFeaturePlugin::PowerControlFeaturePlugin( QObject* parent ) :
 							"This way you do not have to power down each computer by hand." ),
 						QStringLiteral(":/powercontrol/system-shutdown.png") ),
 	m_powerDownNowFeature( QStringLiteral( "PowerDownNow" ),
-								   Feature::Action | Feature::AllComponents,
+								   Feature::Flag::Action | Feature::Flag::AllComponents,
 								   Feature::Uid( "a88039f2-6716-40d8-b4e1-9f5cd48e91ed" ),
 								   m_powerDownFeature.uid(),
 								   tr( "Power down now" ), {}, {} ),
 	m_installUpdatesAndPowerDownFeature( QStringLiteral( "InstallUpdatesAndPowerDown" ),
-								   Feature::Action | Feature::AllComponents,
+								   Feature::Flag::Action | Feature::Flag::AllComponents,
 								   Feature::Uid( "09bcb3a1-fc11-4d03-8cf1-efd26be8655b" ),
 								   m_powerDownFeature.uid(),
 								   tr( "Install updates and power down" ), {}, {} ),
 	m_powerDownConfirmedFeature( QStringLiteral( "PowerDownConfirmed" ),
-								   Feature::Action | Feature::AllComponents,
+								   Feature::Flag::Action | Feature::Flag::AllComponents,
 								   Feature::Uid( "ea2406be-d5c7-42b8-9f04-53469d3cc34c" ),
 								   m_powerDownFeature.uid(),
 								   tr( "Power down after user confirmation" ), {}, {} ),
 	m_powerDownDelayedFeature( QStringLiteral( "PowerDownDelayed" ),
-								   Feature::Action | Feature::AllComponents,
+								   Feature::Flag::Action | Feature::Flag::AllComponents,
 								   Feature::Uid( "352de795-7fc4-4850-bc57-525bcb7033f5" ),
 								   m_powerDownFeature.uid(),
 								   tr( "Power down after timeout" ), {}, {} ),
@@ -173,7 +174,10 @@ bool PowerControlFeaturePlugin::startFeature( VeyonMasterInterface& master, cons
 		return true;
 	}
 
-	if( confirmFeatureExecution( feature, master.mainWindow() ) == false )
+	const auto executeOnAllComputers =
+		computerControlInterfaces.size() >= master.filteredComputerControlInterfaces().size();
+
+	if (confirmFeatureExecution(feature, executeOnAllComputers, master.mainWindow()) == false)
 	{
 		return false;
 	}
@@ -284,7 +288,21 @@ CommandLinePluginInterface::RunResult PowerControlFeaturePlugin::handle_on( cons
 
 
 
-bool PowerControlFeaturePlugin::confirmFeatureExecution( const Feature& feature, QWidget* parent )
+bool PowerControlFeaturePlugin::eventFilter(QObject* watched, QEvent* event)
+{
+	if (event->type() == QEvent::Close &&
+		qobject_cast<QProgressDialog *>(watched))
+	{
+		event->ignore();
+		return true;
+	}
+
+	return QObject::eventFilter(watched, event);
+}
+
+
+
+bool PowerControlFeaturePlugin::confirmFeatureExecution( const Feature& feature, bool all, QWidget* parent )
 {
 	if( VeyonCore::config().confirmUnsafeActions() == false )
 	{
@@ -294,7 +312,8 @@ bool PowerControlFeaturePlugin::confirmFeatureExecution( const Feature& feature,
 	if( feature == m_rebootFeature )
 	{
 		return QMessageBox::question( parent, tr( "Confirm reboot" ),
-									  tr( "Do you really want to reboot the selected computers?" ) ) ==
+									  all ? tr( "Do you really want to reboot <b>ALL</b> computers?" )
+										  : tr( "Do you really want to reboot the selected computers?" ) ) ==
 				QMessageBox::Yes;
 	}
 	else if( feature == m_powerDownFeature ||
@@ -304,7 +323,8 @@ bool PowerControlFeaturePlugin::confirmFeatureExecution( const Feature& feature,
 			 feature == m_powerDownDelayedFeature )
 	{
 		return QMessageBox::question( parent, tr( "Confirm power down" ),
-									  tr( "Do you really want to power down the selected computer?" ) ) ==
+									  all ? tr( "Do you really want to power down <b>ALL</b> computers?" )
+										  : tr( "Do you really want to power down the selected computers?" ) ) ==
 				QMessageBox::Yes;
 	}
 
@@ -406,7 +426,7 @@ static void updateDialog( QProgressDialog* dialog, int newValue )
 
 	if( remainingSeconds <= 0 )
 	{
-		VeyonCore::platform().coreFunctions().powerDown( false );
+		dialog->accept();
 	}
 
 }
@@ -419,6 +439,7 @@ void PowerControlFeaturePlugin::displayShutdownTimeout( int shutdownTimeout )
 	dialog.setMaximum( shutdownTimeout );
 	dialog.setCancelButton( nullptr );
 	dialog.setWindowFlags( Qt::Window | Qt::CustomizeWindowHint | Qt::WindowTitleHint );
+	dialog.installEventFilter(this);
 
 	auto progressBar = dialog.findChild<QProgressBar *>();
 	if( progressBar )
@@ -439,4 +460,6 @@ void PowerControlFeaturePlugin::displayShutdownTimeout( int shutdownTimeout )
 	} );
 
 	dialog.exec();
+
+	VeyonCore::platform().coreFunctions().powerDown(false);
 }
