@@ -1,7 +1,7 @@
 /*
  * ScreenshotFeaturePlugin.h - declaration of ScreenshotFeature class
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -38,7 +38,7 @@ public:
 
 	Plugin::Uid uid() const override
 	{
-		return QStringLiteral("ee322521-f4fb-482d-b082-82a79003afa7");
+		return Plugin::Uid{ QStringLiteral("ee322521-f4fb-482d-b082-82a79003afa7") };
 	}
 
 	QVersionNumber version() const override
