@@ -1,7 +1,7 @@
 /*
  * SystemUserGroupsPlugin.h - declaration of SystemUserGroupsPlugin class
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -37,7 +37,7 @@ public:
 
 	Plugin::Uid uid() const override
 	{
-		return QStringLiteral("2917cdeb-ac13-4099-8715-20368254a367");
+		return Plugin::Uid{ QStringLiteral("2917cdeb-ac13-4099-8715-20368254a367") };
 	}
 
 	QVersionNumber version() const override
