@@ -1,7 +1,7 @@
 /*
  * TextMessageFeaturePlugin.cpp - implementation of TextMessageFeaturePlugin class
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -35,7 +35,7 @@
 TextMessageFeaturePlugin::TextMessageFeaturePlugin( QObject* parent ) :
 	QObject( parent ),
 	m_textMessageFeature( Feature( QStringLiteral( "TextMessage" ),
-								   Feature::Action | Feature::AllComponents,
+								   Feature::Flag::Action | Feature::Flag::AllComponents,
 								   Feature::Uid( "e75ae9c8-ac17-4d00-8f0d-019348346208" ),
 								   Feature::Uid(),
 								   tr( "Text message" ), {},
@@ -135,9 +135,11 @@ bool TextMessageFeaturePlugin::handleFeatureMessage( VeyonWorkerInterface& worke
 
 	if( message.featureUid() == m_textMessageFeature.uid() )
 	{
-		QMessageBox* messageBox = new QMessageBox( static_cast<QMessageBox::Icon>( message.argument( Argument::Icon ).toInt() ),
-												   tr( "Message from teacher" ),
-												   message.argument( Argument::Text ).toString() );
+		auto messageBox = new QMessageBox( static_cast<QMessageBox::Icon>( message.argument( Argument::Icon ).toInt() ),
+										   tr( "Message from teacher" ),
+										   message.argument( Argument::Text ).toString() );
+		messageBox->setTextFormat( Qt::RichText );
+		messageBox->setTextInteractionFlags( Qt::TextBrowserInteraction | Qt::TextSelectableByKeyboard );
 		messageBox->show();
 
 		connect( messageBox, &QMessageBox::accepted, messageBox, &QMessageBox::deleteLater );
