@@ -1,7 +1,7 @@
 /*
  * UserSessionControlPlugin.cpp - implementation of UserSessionControlPlugin class
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -24,6 +24,7 @@
 
 #include <QMessageBox>
 
+#include "PlatformSessionFunctions.h"
 #include "PlatformUserFunctions.h"
 #include "UserLoginDialog.h"
 #include "UserSessionControlPlugin.h"
@@ -34,14 +35,14 @@
 UserSessionControlPlugin::UserSessionControlPlugin( QObject* parent ) :
 	QObject( parent ),
 	m_userLoginFeature( QStringLiteral( "UserLogin" ),
-						Feature::Action | Feature::Master | Feature::Service,
+						Feature::Flag::Action | Feature::Flag::Master | Feature::Flag::Service,
 						Feature::Uid( "7310707d-3918-460d-a949-65bd152cb958" ),
 						Feature::Uid(),
 						tr( "Log in" ), {},
 						tr( "Click this button to log in a specific user on all computers." ),
 						QStringLiteral( ":/usersessioncontrol/login-user.png" ) ),
 	m_userLogoffFeature( QStringLiteral( "UserLogoff" ),
-						 Feature::Action | Feature::Master | Feature::Service,
+						 Feature::Flag::Action | Feature::Flag::Master | Feature::Flag::Service,
 						 Feature::Uid( "7311d43d-ab53-439e-a03a-8cb25f7ed526" ),
 						 Feature::Uid(),
 						 tr( "Log off" ), {},
@@ -95,11 +96,6 @@ bool UserSessionControlPlugin::startFeature( VeyonMasterInterface& master, const
 {
 	Q_UNUSED(master)
 
-	if( confirmFeatureExecution( feature, master.mainWindow() ) == false )
-	{
-		return false;
-	}
-
 	if( feature == m_userLoginFeature )
 	{
 		UserLoginDialog loginDialog( master.mainWindow() );
@@ -115,6 +111,14 @@ bool UserSessionControlPlugin::startFeature( VeyonMasterInterface& master, const
 	}
 	else if( feature == m_userLogoffFeature )
 	{
+		const auto executeOnAllComputers =
+			computerControlInterfaces.size() >= master.filteredComputerControlInterfaces().size();
+
+		if (confirmFeatureExecution(feature, executeOnAllComputers, master.mainWindow()) == false)
+		{
+			return true;
+		}
+
 		return controlFeature( feature.uid(), Operation::Start, {}, computerControlInterfaces );
 	}
 
@@ -139,7 +143,14 @@ bool UserSessionControlPlugin::handleFeatureMessage( VeyonServerInterface& serve
 	}
 	else if( message.featureUid() == m_userLogoffFeature.uid() )
 	{
-		VeyonCore::platform().userFunctions().logoff();
+		if( VeyonCore::platform().sessionFunctions().currentSessionHasUser() )
+		{
+			VeyonCore::platform().userFunctions().logoff();
+		}
+		else
+		{
+			vDebug() << "not logging off since not running in a user session";
+		}
 		return true;
 	}
 
@@ -148,7 +159,7 @@ bool UserSessionControlPlugin::handleFeatureMessage( VeyonServerInterface& serve
 
 
 
-bool UserSessionControlPlugin::confirmFeatureExecution( const Feature& feature, QWidget* parent )
+bool UserSessionControlPlugin::confirmFeatureExecution( const Feature& feature, bool all, QWidget* parent )
 {
 	if( VeyonCore::config().confirmUnsafeActions() == false )
 	{
@@ -158,7 +169,8 @@ bool UserSessionControlPlugin::confirmFeatureExecution( const Feature& feature,
 	if( feature == m_userLogoffFeature )
 	{
 		return QMessageBox::question( parent, tr( "Confirm user logoff" ),
-									  tr( "Do you really want to log off the selected users?" ) ) ==
+									  all ? tr( "Do you really want to log off <b>ALL</b> users?" )
+										  : tr( "Do you really want to log off the selected users?" ) ) ==
 				QMessageBox::Yes;
 	}
 
