@@ -1,7 +1,7 @@
 /*
  * UserSessionControlPlugin.h - declaration of UserSessionControlPlugin class
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -46,7 +46,7 @@ public:
 
 	Plugin::Uid uid() const override
 	{
-		return QStringLiteral("80580500-2e59-4297-9e35-e53959b028cd");
+		return Plugin::Uid{ QStringLiteral("80580500-2e59-4297-9e35-e53959b028cd") };
 	}
 
 	QVersionNumber version() const override
@@ -90,7 +90,7 @@ public:
 							   const FeatureMessage& message ) override;
 
 private:
-	bool confirmFeatureExecution( const Feature& feature, QWidget* parent );
+	bool confirmFeatureExecution( const Feature& feature, bool all, QWidget* parent );
 
 	const Feature m_userLoginFeature;
 	const Feature m_userLogoffFeature;
