@@ -1,7 +1,7 @@
 /*
  * ExternalVncServer.h - declaration of ExternalVncServer class
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -38,7 +38,7 @@ public:
 
 	Plugin::Uid uid() const override
 	{
-		return QStringLiteral("67dfc1c1-8f37-4539-a298-16e74e34fd8b");
+		return Plugin::Uid{ QStringLiteral("67dfc1c1-8f37-4539-a298-16e74e34fd8b") };
 	}
 
 	QVersionNumber version() const override
