@@ -1,7 +1,7 @@
 /*
  * HeadlessVncServer.h - declaration of HeadlessVncServer class
  *
- * Copyright (c) 2020-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2020-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -40,7 +40,7 @@ public:
 
 	Plugin::Uid uid() const override
 	{
-		return QStringLiteral("f626f759-7691-45c0-bd4a-37171d98d219");
+		return Plugin::Uid{ QStringLiteral("f626f759-7691-45c0-bd4a-37171d98d219") };
 	}
 
 	QVersionNumber version() const override
