@@ -1,7 +1,7 @@
 /*
  * BuiltinUltraVncServer.h - declaration of BuiltinUltraVncServer class
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -40,7 +40,7 @@ public:
 
 	Plugin::Uid uid() const override
 	{
-		return QStringLiteral("39d7a07f-94db-4912-aa1a-c4df8aee3879");
+		return Plugin::Uid{ QStringLiteral("39d7a07f-94db-4912-aa1a-c4df8aee3879") };
 	}
 
 	QVersionNumber version() const override
