@@ -1,7 +1,7 @@
 /*
  * WebApiController.h - declaration of WebApiController class
  *
- * Copyright (c) 2020-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2020-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -27,7 +27,6 @@
 #include <QReadWriteLock>
 
 #include "EnumHelper.h"
-#include "FeatureManager.h"
 #include "LockingPointer.h"
 #include "WebApiConnection.h"
 
@@ -75,6 +74,7 @@ public:
 		UnsupportedImageFormat,
 		FramebufferNotAvailable,
 		FramebufferEncodingError,
+		ProtocolMismatch,
 	};
 
 	struct Request
@@ -130,6 +130,8 @@ private:
 		return QStringLiteral("Connection-Uid");
 	}
 
+	static QVariant lookupHeaderField( const Request& request, const QString& fieldName );
+
 	using WebApiConnectionPointer = QSharedPointer<WebApiConnection>;
 	using LockingConnectionPointer = LockingPointer<WebApiConnectionPointer>;
 
@@ -141,7 +143,6 @@ private:
 	Response checkFeature( const QString& featureUid );
 
 	const WebApiConfiguration& m_configuration;
-	const FeatureManager m_featureManager;
 	QMap<QUuid, WebApiConnectionPointer> m_connections{};
 	QReadWriteLock m_connectionsLock;
 
