@@ -1,7 +1,7 @@
 /*
  * WebApiHttpServer.cpp - implementation of WebApiHttpServer class
  *
- * Copyright (c) 2020-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2020-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -64,6 +64,7 @@ static QHttpServerResponse convertResponse( const WebApiController::Response& re
 		case WebApiController::Error::UnsupportedImageFormat: return QHttpServerResponse::StatusCode::ServiceUnavailable;
 		case WebApiController::Error::FramebufferNotAvailable: return QHttpServerResponse::StatusCode::ServiceUnavailable;
 		case WebApiController::Error::FramebufferEncodingError: return QHttpServerResponse::StatusCode::InternalServerError;
+		case WebApiController::Error::ProtocolMismatch: return QHttpServerResponse::StatusCode::NotImplemented;
 		}
 		return QHttpServerResponse::StatusCode::BadRequest;
 	}();
@@ -199,6 +200,15 @@ bool WebApiHttpServer::addRoute( const QString& path,
 			const auto headers = request.headers();
 			const auto data = dataFromRequest<M>( request );
 
+			if( m_threadPool.activeThreadCount() >= m_threadPool.maxThreadCount() )
+			{
+				auto response = convertResponse( WebApiController::Error::ConnectionLimitReached );
+				QFutureInterface<QHttpServerResponse> fi;
+				fi.reportAndMoveResult( std::move(response) );
+				fi.reportFinished();
+				return QFuture<QHttpServerResponse>{ &fi };
+			}
+
 			return QtConcurrent::run( &m_threadPool, [=] {
 				return convertResponse( (m_controller->*controllerMethod)(
 					{ headers, data },
@@ -273,7 +283,7 @@ bool WebApiHttpServer::setupTls()
 	QSslCertificate certificate( certFile.readAll() );
 	if( certificate.isNull() )
 	{
-		vCritical() << m_configuration.tlsCertificateFile() << "does not contain a valid TLS certificate";
+		vCritical() << certFile.fileName() << "does not contain a valid TLS certificate";
 		return false;
 	}
 
@@ -310,7 +320,7 @@ bool WebApiHttpServer::setupTls()
 
 	if( privateKey.isNull() )
 	{
-		vCritical() << m_configuration.tlsCertificateFile() << "does contains an invalid or unsupported TLS private key";
+		vCritical() << privateKeyFile.fileName() << "contains an invalid or unsupported TLS private key";
 		return false;
 	}
 
