@@ -1,7 +1,7 @@
 /*
  * ComputerControlClient.cpp - implementation of the ComputerControlClient class
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -43,6 +43,7 @@ ComputerControlClient::ComputerControlClient( ComputerControlServer* server,
 					  server->accessControlManager() ),
 	m_clientProtocol( vncServerSocket(), vncServerPassword )
 {
+	m_framebufferUpdateTimer.start();
 }
 
 
@@ -66,8 +67,38 @@ bool ComputerControlClient::receiveClientMessage()
 
 	if( messageType == FeatureMessage::RfbMessageType )
 	{
-		return m_server->handleFeatureMessage( socket );
+		return m_server->handleFeatureMessage(this);
+	}
+
+	// filter framebuffer update requests when minimum framebuffer update interval is set
+	if (messageType == rfbFramebufferUpdateRequest && m_minimumFramebufferUpdateInterval > 0)
+	{
+		if (socket->bytesAvailable() < sz_rfbFramebufferUpdateRequestMsg)
+		{
+			return false;
+		}
+
+		const auto messageData = socket->read(sz_rfbFramebufferUpdateRequestMsg);
+		const auto updateRequestMessage = reinterpret_cast<const rfbFramebufferUpdateRequestMsg *>(messageData.constData());
+
+		if (updateRequestMessage->incremental &&
+			m_framebufferUpdateTimer.hasExpired(m_minimumFramebufferUpdateInterval) == false)
+		{
+			// discard update request
+			return true;
+		}
+
+		// forward request to server
+		m_framebufferUpdateTimer.restart();
+		return vncServerSocket()->write(messageData) == messageData.size();
 	}
 
 	return VncProxyConnection::receiveClientMessage();
 }
+
+
+
+void ComputerControlClient::setMinimumFramebufferUpdateInterval(int interval)
+{
+	m_minimumFramebufferUpdateInterval = interval;
+}
