@@ -1,7 +1,7 @@
 /*
  * ComputerControlServer.h - header file for ComputerControlServer
  *
- * Copyright (c) 2006-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -24,10 +24,9 @@
 
 #pragma once
 
-#include <QtCore/QMutex>
-#include <QtCore/QStringList>
+#include <QMutex>
+#include <QtConcurrent>
 
-#include "FeatureManager.h"
 #include "FeatureWorkerManager.h"
 #include "RfbVeyonAuth.h"
 #include "ServerAuthenticationManager.h"
@@ -37,7 +36,9 @@
 #include "VncProxyConnectionFactory.h"
 #include "VncServer.h"
 
-class ComputerControlServer : public QObject, VncProxyConnectionFactory, VeyonServerInterface
+class ComputerControlClient;
+
+class ComputerControlServer : public VeyonServerInterface, VncProxyConnectionFactory
 {
 	Q_OBJECT
 public:
@@ -61,7 +62,7 @@ public:
 		return m_serverAccessControlManager;
 	}
 
-	bool handleFeatureMessage( QTcpSocket* socket );
+	bool handleFeatureMessage(ComputerControlClient* client);
 
 	bool sendFeatureMessageReply( const MessageContext& context, const FeatureMessage& reply ) override;
 
@@ -75,20 +76,25 @@ public:
 		return m_vncServer.serverBasePort();
 	}
 
+	void setMinimumFramebufferUpdateInterval(const MessageContext& context, int interval) override;
+
 private:
 	void checkForIncompleteAuthentication( VncServerClient* client );
 	void showAuthenticationMessage( VncServerClient* client );
 	void showAccessControlMessage( VncServerClient* client );
+	QFutureWatcher<void>* resolveFQDNs( const QStringList& hosts );
 
+	void sendAsyncFeatureMessages(VncProxyConnection* connection);
 	void updateTrayIconToolTip();
 
 	QMutex m_dataMutex;
 	QStringList m_allowedIPs;
 
+	QMap<QString, QString> m_resolvedHostNames;
+
 	QStringList m_failedAuthHosts;
 	QStringList m_failedAccessControlHosts;
 
-	FeatureManager m_featureManager;
 	FeatureWorkerManager m_featureWorkerManager;
 
 	ServerAuthenticationManager m_serverAuthenticationManager;
