@@ -1,7 +1,7 @@
 /*
  * VncProxyServer.cpp - a VNC proxy implementation for intercepting VNC connections
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -103,6 +103,9 @@ void VncProxyServer::acceptConnection()
 																	 m_vncServerPassword,
 																	 this );
 
+	connect(connection, &VncProxyConnection::serverMessageProcessed, this,
+		[=]() { Q_EMIT serverMessageProcessed(connection); }, Qt::DirectConnection );
+
 	connect( connection, &VncProxyConnection::clientConnectionClosed, this, [=]() { closeConnection( connection ); } );
 	connect( connection, &VncProxyConnection::serverConnectionClosed, this, [=]() { closeConnection( connection ); } );
 
