@@ -1,7 +1,7 @@
 /*
  * main.cpp - main file for Veyon Server
  *
- * Copyright (c) 2006-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -22,7 +22,7 @@
  *
  */
 
-#include <QCoreApplication>
+#include <QGuiApplication>
 
 #include "ComputerControlServer.h"
 #include "VeyonConfiguration.h"
@@ -30,7 +30,9 @@
 
 int main( int argc, char **argv )
 {
-	QCoreApplication app( argc, argv );
+	VeyonCore::setupApplicationParameters();
+
+	QGuiApplication app( argc, argv );
 
 	VeyonCore core( &app, VeyonCore::Component::Server, QStringLiteral("Server") );
 
