@@ -35,6 +35,7 @@ FeatureWorkerManagerConnection::FeatureWorkerManagerConnection( VeyonWorkerInter
 																QObject* parent ) :
 	QObject( parent ),
 	m_worker( worker ),
+	m_port(VeyonCore::config().featureWorkerManagerPort() + VeyonCore::sessionId()),
 	m_socket( this ),
 	m_featureUid( featureUid )
 {
@@ -43,8 +44,11 @@ FeatureWorkerManagerConnection::FeatureWorkerManagerConnection( VeyonWorkerInter
 	connect( &m_socket, &QTcpSocket::connected,
 			 this, &FeatureWorkerManagerConnection::sendInitMessage );
 
-	connect( &m_socket, &QTcpSocket::disconnected,
-			 QCoreApplication::instance(), &QCoreApplication::quit );
+	connect(&m_socket, &QTcpSocket::disconnected, this,
+			[=]() {
+		vDebug() << "lost connection to FeatureWorkerManager – exiting";
+		QCoreApplication::instance()->exit(0);
+	}, Qt::QueuedConnection);
 
 	connect( &m_socket, &QTcpSocket::readyRead,
 			 this, &FeatureWorkerManagerConnection::receiveMessage );
@@ -56,6 +60,8 @@ FeatureWorkerManagerConnection::FeatureWorkerManagerConnection( VeyonWorkerInter
 
 bool FeatureWorkerManagerConnection::sendMessage( const FeatureMessage& message )
 {
+	vDebug() << message;
+
 	return message.send( &m_socket );
 }
 
@@ -65,12 +71,10 @@ void FeatureWorkerManagerConnection::tryConnection()
 {
 	if( m_socket.state() != QTcpSocket::ConnectedState )
 	{
-		const auto port = quint16( VeyonCore::config().featureWorkerManagerPort() + VeyonCore::sessionId() );
+		vDebug() << "connecting to FeatureWorkerManager at port" << m_port;
 
-		vDebug() << "connecting to FeatureWorkerManager at port" << port;
-
-		m_socket.connectToHost( QHostAddress::LocalHost, port );
-		m_connectTimer.start( ConnectTimeout );
+		m_socket.connectToHost(QHostAddress::LocalHost, m_port);
+		m_connectTimer.start(ConnectTimeout);
 	}
 }
 
