@@ -1,7 +1,7 @@
 /*
  * main.cpp - main file for Veyon Feature Worker
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -23,12 +23,16 @@
  */
 
 #include <QApplication>
+#include <QIcon>
 
+#include "Feature.h"
 #include "VeyonWorker.h"
 
 
 int main( int argc, char **argv )
 {
+	VeyonCore::setupApplicationParameters();
+
 	QApplication app( argc, argv );
 	app.setWindowIcon( QIcon( QStringLiteral(":/core/icon64.png") ) );
 
@@ -39,8 +43,8 @@ int main( int argc, char **argv )
 		qFatal( "Not enough arguments (feature)" );
 	}
 
-	const auto featureUid = arguments[1];
-	if( QUuid( featureUid ).isNull() )
+	const auto featureUid = Feature::Uid{arguments[1]};
+	if( featureUid.isNull() )
 	{
 		qFatal( "Invalid feature UID given" );
 	}
